@@ -100,7 +100,7 @@ void create_cal_widgets(
 			XmVaCASCADEBUTTON, s[3], 'V',
 			XmVaCASCADEBUTTON, s[4], 'H',
 			NULL);
-	if (w = XtNameToWidget(menubar, "button_4"))
+	if ((w = XtNameToWidget(menubar, "button_4")))
 		XtVaSetValues(menubar, XmNmenuHelpWidget, w, 0);
 	for (n=0; n < 5; n++)
 		XmStringFree(s[n]);
@@ -334,9 +334,9 @@ void create_view(
 Widget create_view_form(
 	Widget		*shell,		/* if shell exists, widget, else &0 */
 	Widget		parent,		/* parent widget (mainview) if share */
-	int		view,		/* m, w, y, o, d */
-	int		xs,		/* requested form width */
-	int		ys,		/* requested form height */
+	UNUSED int	view,		/* m, w, y, o, d */
+	UNUSED int	xs,		/* requested form width */
+	UNUSED int	ys,		/* requested form height */
 	char		*name)		/* window name */
 {
 	Widget		form;		/* form to create to draw view into */
@@ -551,9 +551,9 @@ void set_widget_size(
 
 /*ARGSUSED*/
 static void filemenu_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	switch (item) {
 	  case 0:						/* file list */
@@ -562,7 +562,7 @@ static void filemenu_callback(
 
 	  case 1: {						/* reread */
 		char *errmsg;
-		if (errmsg = parse_holidays(curr_year, FALSE))
+		if ((errmsg = parse_holidays(curr_year, FALSE)))
 			create_error_popup(mainmenu.cal, 0, errmsg);
 		if (can_edit_appts()) {
 			read_mainlist();
@@ -588,9 +588,9 @@ static void filemenu_callback(
 static int period[5] = {1, 7, 31, 90, 366};
 /*ARGSUSED*/
 static void delpast_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	if (can_edit_appts())
 		if (item < 5 && recycle_all(mainlist, TRUE, period[item])) {
@@ -601,9 +601,9 @@ static void delpast_callback(
 
 /*ARGSUSED*/
 static void configmenu_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	if (!can_edit_appts())
 		return;
@@ -627,7 +627,7 @@ static void configmenu_callback(
 static void language_callback(
 	Widget				widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	if (config.language)
 		free(config.language);
@@ -640,9 +640,9 @@ static void language_callback(
 
 /*ARGSUSED*/
 static void search_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	time_t				now;		/* curr date, 0:00 */
 	struct tm			*tm;
@@ -714,9 +714,9 @@ static void list_by_user(
 
 /*ARGSUSED*/
 static void view_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	time_t time = get_time();
 	struct tm *tm = time_to_tm(time);
@@ -765,7 +765,7 @@ static void view_callback(
 
 /*ARGSUSED*/
 static void help_pulldown(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -775,7 +775,7 @@ static void help_pulldown(
 	switch (item) {
 	  case 0:						/* context */
 		cursor = XCreateFontCursor(display, XC_question_arrow);
-		if (w = XmTrackingLocate(mainwindow, cursor, False)) {
+		if ((w = XmTrackingLocate(mainwindow, cursor, False))) {
 			data->reason = XmCR_HELP;
 			XtCallCallbacks(w, XmNhelpCallback, &data);
 		}
