@@ -91,6 +91,13 @@
 #define PR_YEAR		4
 #define PR_YOV		5
 
+/* gcc doesn't support turning off stupid warning messages selectively */
+#if defined(__GNUC__)
+#define UNUSED __attribute__((unused))	/* Flag variable as unused */
+#else /* not __GNUC__ */
+#define UNUSED
+#endif
+
 
 struct config {			/* global configuration data */
 	time_t		tzone;		/* timezone with dst figured in */
