@@ -51,16 +51,16 @@ time_t length_of_month(
  */
 
 BOOL recycle_all(
-	struct plist		*list,		/* list to scan */
-	BOOL			del,		/* auto-remove obsolete? */
-	int			days)		/* if del, keep if age < days*/
+	struct plist	*list,		/* list to scan */
+	BOOL		del,		/* auto-remove obsolete? */
+	int		days)		/* if del, keep if age < days*/
 {
-	register struct entry	*ep;		/* current entry considered */
-	int			n;		/* entry counter */
-	int			u;		/* user[] index */
-	time_t			now;		/* current time */
-	time_t			time;		/* next trigger time */
-	BOOL			chg = FALSE;	/* TRUE if list was changed */
+	struct entry	*ep;		/* current entry considered */
+	int		n;		/* entry counter */
+	int		u;		/* user[] index */
+	time_t		now;		/* current time */
+	time_t		time;		/* next trigger time */
+	BOOL		chg = FALSE;	/* TRUE if list was changed */
 
 	now = get_time();
 	for (n=0; n < list->nentries; n++) {
@@ -121,26 +121,26 @@ BOOL recycle_all(
 	}}
 
 int recycle(
-	register struct entry	*entry,		/* entry to test */
-	time_t			today,		/* today (time is ignored) */
-	register time_t		*ret)		/* returned next trigger time*/
+	struct entry	*entry,		/* entry to test */
+	time_t		today,		/* today (time is ignored) */
+	time_t		*ret)		/* returned next trigger time*/
 {
-	struct tm		tm1;		/* first trigger m/d/y ever */
-	struct tm		tm1w;		/* same for n-days-ahead warn*/
-	struct tm		tm;		/* time to m/d/y h:m:s conv */
-	struct tm		tmw;		/* same for n-days-ahead warn*/
-	time_t			day;		/* <today> with no time info */
-	long			tday;		/* entry date with no time */
-	long			wday;		/* entry warn with no time */
-	long			end;		/* don't search too far */
-	long			every;		/* period in days */
-	BOOL			simple;		/* no daily,monthly,yrly,warn*/
-	int			mlen  = 0;	/* # of days in test month */
-	int			mlenw = 0;	/* same for n-days-ahead warn*/
-	register time_t		warn;		/* n-days-ahead warn period */
-	register long		w = entry->rep_weekdays;
-	register long		d = entry->rep_days;
-	register time_t		last = entry->rep_last;
+	struct tm	tm1;		/* first trigger m/d/y ever */
+	struct tm	tm1w;		/* same for n-days-ahead warn*/
+	struct tm	tm;		/* time to m/d/y h:m:s conv */
+	struct tm	tmw;		/* same for n-days-ahead warn*/
+	time_t		day;		/* <today> with no time info */
+	long		tday;		/* entry date with no time */
+	long		wday;		/* entry warn with no time */
+	long		end;		/* don't search too far */
+	long		every;		/* period in days */
+	BOOL		simple;		/* no daily,monthly,yrly,warn*/
+	int		mlen  = 0;	/* # of days in test month */
+	int		mlenw = 0;	/* same for n-days-ahead warn*/
+	time_t		warn;		/* n-days-ahead warn period */
+	long		w = entry->rep_weekdays;
+	long		d = entry->rep_days;
+	time_t		last = entry->rep_last;
 
 	*ret = entry->time;
 	warn = entry->days_warn ? entry->time - entry->days_warn : 0;
@@ -156,7 +156,7 @@ int recycle(
 			 && !entry->rep_every  && !entry->rep_weekdays)
 		return(2);
 					/* have passed last-trigger date? */
-	if (last && *ret > last + 86400-1)
+	if (last && today > last + 86400-1)
 		return(2);
 					/* hit simple n-days-ahead warning? */
 	if (warn && !w && !d && !entry->rep_yearly
@@ -216,22 +216,22 @@ int recycle(
 				if (!(w & 0x3f00))
 					return(1);
 				if ((w & 0x0100 << (tm.tm_mday-1) / 7) ||
-				    (w & 0x2000) && tm.tm_mday+7 > mlen)
+				   ((w & 0x2000) && tm.tm_mday+7 > mlen))
 					return(1);
 			}
 			if (warn && (w & 1 << tmw.tm_wday)) {
 				if (!(w & 0x3f00))
 					return(3);
 				if ((w & 0x0100 << (tmw.tm_mday-1) / 7) ||
-				    (w & 0x2000) && tmw.tm_mday+7 > mlenw)
+				   ((w & 0x2000) && tmw.tm_mday+7 > mlenw))
 					return(3);
 			}
 					/* got a match of a monthly repeat? */
 			if (day >= tday && ((d & 1 << tm.tm_mday) ||
-					    (d & 1) && tm.tm_mday == mlen))
+					   ((d & 1) && tm.tm_mday == mlen)))
 				return(1);
 			if (warn && ((d & 1 << tmw.tm_mday) ||
-				     (d & 1) && tmw.tm_mday == mlenw))
+				    ((d & 1) && tmw.tm_mday == mlenw)))
 				return(3);
 					/* no match, proceed with next day */
 			INC_TM(tm);
@@ -250,17 +250,17 @@ int recycle(
  */
 
 BOOL move_todo_entry(
-	register struct entry	*entry,		/* entry to test */
-	time_t			today)		/* today (time is ignored) */
+	struct entry	*entry,		/* entry to test */
+	time_t		today)		/* today (time is ignored) */
 {
-	BOOL			ret = FALSE;
+	BOOL		ret = FALSE;
 
 	if (entry->todo) {
 		today -= today % 86400;
 		if (entry->rep_last) {
-			if (ret = entry->rep_last < today)
+			if ((ret = entry->rep_last < today))
 				entry->rep_last = today;
-		} else if (ret = entry->time < today)
+		} else if ((ret = entry->time < today))
 			entry->time = today + entry->time % 86400;
 	}
 	return(ret);
