@@ -101,13 +101,13 @@ static char *nth_name[] = { "every...", "first...", "second...",
 
 void create_recycle_popup(void)
 {
-	Widget			frame, frame2, form, form2, rowcol, w;
-	int			day;		/* weekdays and month days */
-	char			buf[10];	/* month day names */
-	register struct entry	*ep = &edit.entry;
-	Arg			args[20];
-	int			n;
-	Atom			closewindow;
+	Widget		frame, frame2, form, form2, rowcol, w;
+	int		day;		/* weekdays and month days */
+	char		buf[10];	/* month day names */
+	struct entry	*ep = &edit.entry;
+	Arg		args[20];
+	int		n;
+	Atom		closewindow;
 
 	destroy_recycle_popup();
 
@@ -427,9 +427,9 @@ void create_recycle_popup(void)
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_recycle_popup();
 }
@@ -437,7 +437,7 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void wkday_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -452,11 +452,11 @@ static void wkday_callback(
 
 /*ARGSUSED*/
 static void nth_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
-	register struct entry		*ep = &edit.entry;
+	struct entry			*ep = &edit.entry;
 	int				i;
 	Arg				args;
 
@@ -479,7 +479,7 @@ static void nth_callback(
 
 /*ARGSUSED*/
 static void day_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -494,8 +494,8 @@ static void day_callback(
 
 /*ARGSUSED*/
 static void every_callback(
-	Widget				widget,
-	int				item,
+	UNUSED Widget			widget,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set) {
@@ -514,8 +514,8 @@ static void every_callback(
 /*ARGSUSED*/
 static void every_text_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextGetString(widget);
 	Arg				args;
@@ -531,8 +531,8 @@ static void every_text_callback(
 
 /*ARGSUSED*/
 static void yearly_callback(
-	Widget				widget,
-	int				item,
+	UNUSED Widget			widget,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	edit.entry.rep_yearly = data->set;
@@ -543,8 +543,8 @@ static void yearly_callback(
 
 /*ARGSUSED*/
 static void last_callback(
-	Widget				widget,
-	int				item,
+	UNUSED Widget			widget,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set) {
@@ -567,8 +567,8 @@ static void last_callback(
 /*ARGSUSED*/
 static void last_text_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char				*text = XmTextGetString(widget);
 	Arg				args;
