@@ -11,7 +11,7 @@
  *
  * This program uses the $PATH environment variable to find programs.
  *
- * Author: thomas@bitrot.in-berlin.de (Thomas Driemeyer)
+ * Author: thomas@bitrot.de (Thomas Driemeyer)
  */
 
 			/* dummies for prototype declarations in config.h */
@@ -113,9 +113,10 @@ static time_t		last_alarm;	/* Last time alarm was checked for */
 int			curr_year;	/* dummy for DST calculating routines*/
 Widget			mainwindow;	/* dummy for error popup in network.c*/
 					/* dummy functions, never used: */
-int	  write_one_entry    (int (*a)(), struct entry *e) {return(0);}
-XtInputId register_X_input   (int a)			   {return(0);}
-void	  unregister_X_input (XtInputId a)		   {}
+int	  write_one_entry    (UNUSED int (*a)(), UNUSED struct entry *e)
+							{return(0);}
+XtInputId register_X_input   (UNUSED int a)		{return(0);}
+void	  unregister_X_input (UNUSED XtInputId a)	{}
 
 
 int main(
@@ -123,7 +124,7 @@ int main(
 	char			**argv)
 {
 	PID_T			pid;		/* pid in lockfile */
-	int			reason;		/* what triggers next? */
+	int			reason=0;	/* what triggers next? */
 	time_t			now, twait;	/* now and wait for trigger */
 	time_t			total_wait;
 	time_t			ancient=ANCIENT;/* initially accept past trig*/
@@ -190,11 +191,12 @@ int main(
 #ifdef ITIMER
 	signal(SIGALRM, sighand);
 #endif
-	if (!startup_lock(resolve_tilde(PLANDLOCK), opt_k || opt_K))
+	if (!startup_lock(TRUE, opt_k || opt_K)) {
 		if (opt_k || opt_K)
 			fatal(_("cannot kill existing %s daemon"), progname);
 		else
 			fatal(_("another daemon exists, use %s -k"), progname);
+	}
 	if (opt_K) {
 		(void)unlink(lockpath);
 		exit(0);
@@ -246,7 +248,7 @@ int main(
 		twait = HIBERNATE;
 	    total_wait = twait;
 	    while (total_wait && !reread) {
-		twait = total_wait>1*60 ? 1*60 : total_wait;
+		twait = total_wait > 1*60 ? 1*60 : total_wait;
 		if (debug)
 		    printf(_("%s: sleeping for %d:%02d:%02d\n"), progname,
 			   (int)twait/3600, (int)(twait/60)%60, (int)twait%60);
@@ -290,7 +292,7 @@ int main(
 #else
 		    short pid = getpid();
 		    setutent();
-		    while (u = getutent())
+		    while ((u = getutent()))
 			if (u->ut_type == USER_PROCESS &&
 			    u->ut_pid != pid &&
 			    !strncmp(pw->pw_name, u->ut_user, 8)) {
@@ -308,10 +310,10 @@ int main(
 		if (logged_in) {
 		    got_login = TRUE;
 		    if (debug)
-			printf(_("%s: utmp works, watching for logout"),
+			printf(_("%s: utmp works, watching for logout\n"),
 							    progname);
 		} else if (opt_s && debug)
-			printf(_("%s: logged out, keeping quiet"), progname);
+			printf(_("%s: logged out, keeping quiet\n"), progname);
 		total_wait -= twait;
 	    }
 	}
@@ -327,10 +329,10 @@ int main(
  */
 
 static void alert(
-	register struct entry	*entry,		/* entry that triggered */
-	int			reason)		/* why: 1=early,2=late,3=time*/
+	struct entry	*entry,		/* entry that triggered */
+	int		reason)		/* why: 1=early,2=late,3=time*/
 {
-	char			cmd[4096];	/* command to execute */
+	char		cmd[4096];	/* command to execute */
 
 	signal(SIGPIPE, SIG_IGN);		/* survive death of notifier */
 	switch(reason) {
@@ -368,7 +370,7 @@ static void alert(
 					entry->note ? entry->note : "");
 			exec_program(entry, cmd, FALSE);
 		}
-		if (entry->script)
+		if (entry->script) {
 			if (!config.insecure_script &&
 						(!entry->user || !entry->id))
 				exec_program(entry, entry->script, TRUE);
@@ -376,6 +378,7 @@ static void alert(
 				fprintf(stderr,
 					_("%s: ignoring insecure script"),
 								progname);
+		}
 	}
 }
 
@@ -388,11 +391,12 @@ static void alert(
  */
 
 static void popup_window(
-	int			reason,		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry)		/* entry that triggered */
+	int		reason,		/* why: 1=early,2=late,3=time*/
+	struct entry	*entry)		/* entry that triggered */
 {
-	char			prog[1024];	/* path of notifier program */
-	char			cmd[2048];	/* command string */
+	char		prog[1024];	/* path of notifier program */
+	char		cmd[2048];	/* command string */
+	int		timeout = (int)config.wintimeout;
 
 	if (opt_t) {
 		printf("*** %s\n*** %s\n", get_subject(reason, entry, FALSE),
@@ -403,10 +407,26 @@ static void popup_window(
 		fprintf(stderr, _("%s: %s: not found\n"), progname, ALARM_FN);
 		return;
 	}
-	if (config.wintimeout > 59)
+	/* kill early warn window when late warn window appears */
+	if (reason == 1 && entry->late_warn
+			&& (timeout < 60 ||
+			    timeout > entry->early_warn - entry->late_warn))
+		timeout = entry->early_warn - entry->late_warn;
+
+	/* kill early warn window when main alarm appears */
+	if (reason == 1 && !entry->noalarm
+			&& (timeout < 60 || timeout > entry->early_warn))
+		timeout = entry->early_warn;
+
+	/* kill late warn window when main alarm appears */
+	if (reason == 2 && !entry->noalarm
+			&& (timeout < 60 || timeout > entry->late_warn))
+		timeout = entry->late_warn;
+
+	if (timeout > 59)
 		sprintf(cmd, "%s -%d -e%d -t\1%s\2 -s\1%s\2 -i\1%s\2",
 					prog, reason,
-					(int)config.wintimeout/60,
+					timeout/60,
 					get_subject(reason, entry, FALSE),
 					get_subtitle(entry),
 					get_icontitle(reason, entry));
@@ -427,11 +447,11 @@ static void popup_window(
  */
 
 static void send_mail(
-	int			reason,		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry)		/* entry that triggered */
+	int		reason,		/* why: 1=early,2=late,3=time*/
+	struct entry	*entry)		/* entry that triggered */
 {
-	char			cmd[2048];	/* command string */
-	char			subject[512];	/* quoted subject */
+	char		cmd[2048];	/* command string */
+	char		subject[512];	/* quoted subject */
 
 	if (!config.mailer || !*config.mailer) {
 		fprintf(stderr, _("%s: no mailer defined\n"), progname);
@@ -480,7 +500,7 @@ static char *get_message(
 
 /*ARGSUSED*/
 static void reaper(
-	int			sig)
+	UNUSED int		sig)
 {
 	char			path[40];	/* script to delete */
 #if (defined BSD && !defined OSF && !defined __FreeBSD__)
@@ -497,21 +517,21 @@ static void reaper(
 
 
 static void exec_program(
-	register struct entry	*entry,		/* entry that triggered */
-	char			*program,	/* program or script to exec */
-	BOOL			script)		/* run program in a subshell */
+	struct entry	*entry,		/* entry that triggered */
+	char		*program,	/* program or script to exec */
+	BOOL		script)		/* run program in a subshell */
 {
-	int			fd[2];		/* pipe to child process */
-	PID_T			pid;		/* child process id */
-	char			*p = program;	/* source command line */
-	char			*q = program;	/* target command line */
-	char			*argv[100];	/* argument vector */
-	int			argc = 0;	/* argument counter */
-	char			scriptname[40];	/* if script, temp file name */
-	int			quote;		/* argument quote flags */
-	char			*msg;		/* msg to print */
-	long			msgsize;	/* strlen(msg) */
-	char			progpath[1024];	/* path name of executable */
+	int		fd[2];		/* pipe to child process */
+	PID_T		pid;		/* child process id */
+	char		*p = program;	/* source command line */
+	char		*q = program;	/* target command line */
+	char		*argv[100];	/* argument vector */
+	int		argc = 0;	/* argument counter */
+	char		scriptname[40];	/* if script, temp file name */
+	int		quote;		/* argument quote flags */
+	char		*msg;		/* msg to print */
+	long		msgsize;	/* strlen(msg) */
+	char		progpath[1024];	/* path name of executable */
 
 	if (!script) {				/* build arguments */
 		if (!p) return;
@@ -553,7 +573,7 @@ static void exec_program(
 
 		if (!find_file(progpath, argv[0], TRUE)) {
 			FILE *err;
-			if (err = fopen("/dev/console", "w")) {
+			if ((err = fopen("/dev/console", "w"))) {
 				fprintf(err, _("%s: %s: not found\n"),
 							progname, argv[0]);
 				fclose(err);
@@ -649,8 +669,8 @@ static void write_script(
 		exit(1);
 	}
 	len = strlen(program);
-	if (program[0] != '#' && program[1] != '!' &&
-	    write(fd, "#!/bin/sh\n", 10) != 10 ||
+	if ((program[0] != '#' && program[1] != '!' &&
+	    write(fd, "#!/bin/sh\n", 10) != 10) ||
 	    write(fd, program, len) != len) {
 		int err = errno;
 		fprintf(stderr, _("%s: can't write to %s: "), progname,
@@ -891,13 +911,13 @@ static void sprintmime(
  */
 
 static char *get_subject(
-	int			reason,		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry,		/* entry that triggered */
-	BOOL			withnote)	/* append note string too */
+	int		reason,		/* why: 1=early,2=late,3=time*/
+	struct entry	*entry,		/* entry that triggered */
+	BOOL		withnote)	/* append note string too */
 {
-	static char		msg[512];
-	time_t			time = (entry->time % 86400) / 60;
-	char			ampm = 0;
+	static char	msg[512];
+	time_t		time = (entry->time % 86400) / 60;
+	char		ampm = 0;
 
 	if (config.ampm) {
 		ampm = time < 12*60 ? 'a' : 'p';
@@ -933,11 +953,11 @@ static char *get_subject(
  */
 
 static char *get_subtitle(
-	register struct entry	*entry)		/* entry that triggered */
+	struct entry	*entry)		/* entry that triggered */
 {
-	static char		msg[160];
-	time_t			time;
-	char			ampm = 0;
+	static char	msg[160];
+	time_t		time;
+	char		ampm = 0;
 
 	*msg = 0;
 	if (entry->user)
@@ -973,12 +993,12 @@ static char *get_subtitle(
  */
 
 static char *get_icontitle(
-	int			reason,		/* why: 1=early,2=late,3=time*/
-	register struct entry	*entry)		/* entry that triggered */
+	int		reason,		/* why: 1=early,2=late,3=time*/
+	struct entry	*entry)		/* entry that triggered */
 {
-	static char		msg[20];
-	time_t			time = (entry->time % 86400) / 60;
-	char			ampm = 0;
+	static char	msg[20];
+	time_t		time = (entry->time % 86400) / 60;
+	char		ampm = 0;
 
 	if (config.ampm) {
 		ampm = time < 12*60 ? 'a' : 'p';
@@ -1028,8 +1048,8 @@ static void sighand(
  */
 
 void create_error_popup(
-	void		*widget,
-	int		error,
+	UNUSED void	*widget,
+	UNUSED int	error,
 	char		*fmt, ...)
 {
 	va_list		parm;
@@ -1055,7 +1075,7 @@ void update_last_alarm(void)
 {
 	FILE		*fp;
 
-	if (fp = fopen(resolve_tilde(PLAND_PATH), "w")) {
+	if ((fp = fopen(resolve_tilde(PLAND_PATH), "w"))) {
 		fprintf(fp, "%ld", last_alarm);
 		if (debug)
 			printf(_("recorded last alarm: %ld\n"), last_alarm);
@@ -1076,7 +1096,7 @@ time_t read_last_alarm(void)
 	time_t		result;
 	FILE		*fp;
 
-	if (fp = fopen(resolve_tilde(PLAND_PATH), "r")) {
+	if ((fp = fopen(resolve_tilde(PLAND_PATH), "r"))) {
 		fscanf(fp,"%ld",&result);
 		if (debug)
 			printf(_("reading last alarm: %ld\n"), result);
