@@ -74,7 +74,7 @@ void build_day(
 			if (omit_all || lookup.trigger >= date + 86400)
 				break;
 			ep = &mainlist->entry[lookup.index];
-			if (ep->hide_in_d || ep->private && omit_priv)
+			if (ep->hide_in_d || (ep->private && omit_priv))
 				continue;
 			u = name_to_user(ep->user);
 			if (user[u].suspend_d)
