@@ -62,27 +62,27 @@ extern struct holiday	sm_holiday[366];/* full-line texts under, and small */
  */
 
 MOUSE locate_in_day_calendar(
-	struct entry		**epp,		/* returned entry or 0 */
-	BOOL			*warn,		/* is *epp an n-days-ahead w?*/
-	time_t			*time,		/* if *epp=0, clicked where */
-	time_t			*trigger,	/* if *epp=0, entry trigger */
-	int			*xp,		/* if M_INSIDE, rubber box */
-	int			*yp,
-	int			*xsp,		/* position and size */
-	int			*ysp,
-	int			xc,		/* pixel pos clicked */
-	int			yc)
+	struct entry	**epp,		/* returned entry or 0 */
+	BOOL		*warn,		/* is *epp an n-days-ahead w?*/
+	time_t		*time,		/* if *epp=0, clicked where */
+	time_t		*trigger,	/* if *epp=0, entry trigger */
+	int		*xp,		/* if M_INSIDE, rubber box */
+	int		*yp,
+	int		*xsp,		/* position and size */
+	int		*ysp,
+	int		xc,		/* pixel pos clicked */
+	int		yc)
 {
-	register struct config	*c = &config;
-	struct weeknode		*vert, *horz;	/* yov node scan pointers */
-	register struct entry	*ep;		/* entry to test */
-	int			d;		/* day strip counter */
-	int			x0, y0;		/* XY start coord of day box*/
-	int			x, y;		/* upper left of day bk box */
-	int			xs;		/* width of bar col w/ gaps */
-	time_t			bt;		/* start time of bar */
-	int			b, e;		/* Y start end end pos of bar*/
-	int			yend;		/* bottom margin of chart */
+	struct config	*c = &config;
+	struct weeknode	*vert, *horz;	/* yov node scan pointers */
+	struct entry	*ep;		/* entry to test */
+	int		d;		/* day strip counter */
+	int		x0, y0;		/* XY start coord of day box*/
+	int		x, y;		/* upper left of day bk box */
+	int		xs;		/* width of bar col w/ gaps */
+	time_t		bt;		/* start time of bar */
+	int		b, e;		/* Y start end end pos of bar*/
+	int		yend;		/* bottom margin of chart */
 
 	x0 = c->day_margin + c->day_hourwidth + 2;
 	y0 = c->day_margin + c->day_title + 2 * c->day_headline + 2;
@@ -150,7 +150,7 @@ MOUSE locate_in_day_calendar(
 				return(M_RIGHT);
 		    }
 		}
-		x0 += day.nlines[d] * xs + c->day_margin;
+		x0 += day.nlines[d] * xs + c->day_margin + c->day_hourwidth;
 	    }
 	if (epp)
 		*epp = 0;
@@ -202,20 +202,20 @@ void print_day_calendar(
 
 static void gen_day(void)
 {
-	register struct config	*c = &config;
-	time_t			today;		/* today's date */
-	char			buf[40], *p;	/* text to print */
-	int			d, h, l;	/* day, hour, text length */
-	int			x, xs;		/* appt bar pos, col width */
-	int			x0, y0;		/* top left inside line box */
-	int			dx, dy;		/* size inside day line box */
-	int			cy_d;		/* character height */
-	struct weeknode		*vert, *horz;	/* day node scan pointers */
-	struct holiday		*hp, *shp, *holp;/* to check for holidays */
-	struct tm		*tm;		/* today's date as m/d/y */
+	struct config	*c = &config;
+	time_t		today;		/* today's date */
+	char		buf[40], *p;	/* text to print */
+	int		d, h, l;	/* day, hour, text length */
+	int		x, xs;		/* appt bar pos, col width */
+	int		x0, y0;		/* top left inside line box */
+	int		dx, dy;		/* size inside day line box */
+	int		cy_d;		/* character height */
+	struct weeknode	*vert, *horz;	/* day node scan pointers */
+	struct holiday	*hp, *shp, *holp;/* to check for holidays */
+	struct tm	*tm;		/* today's date as m/d/y */
 #ifdef JAPAN
-	strpack			partialstr[MAXPARTIALSTRING];
-	unsigned char		strpool[MAXPARTIALCHAR];
+	strpack		partialstr[MAXPARTIALSTRING];
+	unsigned char	strpool[MAXPARTIALCHAR];
 #endif
 
 	x0 = c->day_margin;
@@ -229,31 +229,31 @@ static void gen_day(void)
 	strcat(buf, mkdatestring(curr_day + (c->day_ndays-1)*86400));
 	g_setcolor(COL_WTITLE);
 	g_setfont(FONT_WTITLE);
-	g_drawtext((day.canvas_xs - strlen_in_pixels(buf, FONT_WTITLE))/2, 
+	g_drawtext(c->day_margin + c->day_hourwidth + 2,
 		   c->day_margin + c->day_title * 3/4,
 		   buf, strlen(buf));
-
-	g_setcolor(COL_WDAY);					/* hour col */
-	g_setfont(FONT_WHOUR);
-	for (h=0; h <= c->day_maxhour-c->day_minhour; h++) {
-		p = mktimestring((h + c->day_minhour) * 3600, FALSE);
-		l = strlen_in_pixels(p, FONT_WDAY);
-		g_drawtext(x0 + (c->day_hourwidth - l) / 2,
-			   y0 + c->day_hourheight * h + cy_d/2 -2,
-			   p, strlen(p));
-	}
-	x0 += c->day_hourwidth + 2;
 								/* holidays */
 	tm = time_to_tm(curr_day);
-	if (p = parse_holidays(tm->tm_year, FALSE))
+	if ((p = parse_holidays(tm->tm_year, FALSE)))
 		create_error_popup(mainmenu.cal, 0, p);
 	shp = &sm_holiday[tm->tm_yday];
 	hp  =    &holiday[tm->tm_yday];
 
 	for (d=0; d < c->day_ndays; d++, hp++, shp++) {		/* day loop */
+
+		g_setcolor(COL_WDAY);				/* hour col */
+		g_setfont(FONT_WHOUR);
+		for (h=0; h <= c->day_maxhour-c->day_minhour; h++) {
+			p = mktimestring((h + c->day_minhour) * 3600, FALSE);
+			l = strlen_in_pixels(p, FONT_WDAY);
+			g_drawtext(x0 + (c->day_hourwidth - l) / 2,
+				   y0 + c->day_hourheight * h + cy_d/2 -2,
+				   p, strlen(p));
+		}
+		x0 += c->day_hourwidth + 2;
 		tm = time_to_tm(curr_day + d*86400);
 		if (tm->tm_yday == 0) {				/* new year? */
-			if (p = parse_holidays(tm->tm_year, FALSE))
+			if ((p = parse_holidays(tm->tm_year, FALSE)))
 				create_error_popup(mainmenu.cal, 0, p);
 			shp = &sm_holiday[0];
 			hp  =    &holiday[0];
@@ -271,7 +271,7 @@ static void gen_day(void)
 		g_setfont(FONT_WHOUR);
 		p = mkdatestring(curr_day + d * 86400);
 		truncate_string(p, dx, FONT_WHOUR);
-		g_drawtext(x0, y0-4-c->day_headline, p, strlen(p));
+		g_drawtext(x0, y0+4-c->day_headline, p, strlen(p));
 								/* holiday */
 		if ((holp = hp->string ? hp : shp)->string) {
 			g_setcolor(holp->stringcolor ? holp->stringcolor :
@@ -319,18 +319,18 @@ static void gen_day(void)
  */
 
 static void draw_bar(
-	struct weeknode		*node,		/* entry node to print */
-	int			color,		/* color, 0..7 */
-	int			x,		/* top left pos in canvas */
-	int			y)
+	struct weeknode	*node,		/* entry node to print */
+	int		color,		/* color, 0..7 */
+	int		x,		/* top left pos in canvas */
+	int		y)
 {
-	register struct entry	*ep = node->entry;
-	register struct config	*c = &config;
-	time_t			tod;		/* clipped appt time of day */
-	int			yend;		/* right margin of chart */
-	int			w[2], b, e;	/* early/late, begin, end */
-	int			i;		/* warning counter, 0..1 */
-	char			msg[256];
+	struct entry	*ep = node->entry;
+	struct config	*c = &config;
+	time_t		tod;		/* clipped appt time of day */
+	int		yend;		/* right margin of chart */
+	int		w[2], b, e;	/* early/late, begin, end */
+	int		i;		/* warning counter, 0..1 */
+	char		msg[256];
 
 	tod  = BOUND(TOD(ep->time), c->day_minhour*3600, c->day_maxhour*3600);
 	yend = y + c->day_hourheight * (c->day_maxhour - c->day_minhour);
