@@ -78,17 +78,17 @@ static void got_new_user(
  */
 
 void got_entry_press(
-	struct listmenu		*lw,		/* which menu */
-	int			x,		/* which column/row */
-	int			y,
-	int			on,		/* enable radio but: on/off */
-	int			shift)		/* arrow but: 1=shift key */
+	struct listmenu	*lw,		/* which menu */
+	int		x,		/* which column/row */
+	int		y,
+	int		on,		/* enable radio but: on/off */
+	int		shift)		/* arrow but: 1=shift key */
 {
-	register struct entry	*ep;		/* affected entry */
-	int			num;		/* number of entries so far */
-	time_t			now, temp;	/* current time */
-	int			inc;		/* if arrow button, +1 or -1 */
-	int			xp = 0;		/* after inc/dec, reprint x */
+	struct entry	*ep;		/* affected entry */
+	int		num;		/* number of entries so far */
+	time_t		now, temp;	/* current time */
+	int		inc;		/* if arrow button, +1 or -1 */
+	int		xp = 0;		/* after inc/dec, reprint x */
 
 	destroy_user_sel_popup();
 	num = lw->sublist ? lw->sublist->nentries : 0;
@@ -430,14 +430,14 @@ void undo_new_entry(void)
  */
 
 void got_entry_text(
-	struct listmenu		*lw,		/* which menu */
-	int			x,		/* which column/row */
-	int			y,
-	char			*text)		/* text input by user */
+	struct listmenu	*lw,		/* which menu */
+	int		x,		/* which column/row */
+	int		y,
+	char		*text)		/* text input by user */
 {
-	register struct entry	*ep;		/* affected entry */
-	register char		*p;		/* to remove trailing \n's */
-	time_t			temp;
+	struct entry	*ep;		/* affected entry */
+	char		*p;		/* to remove trailing \n's */
+	time_t		temp;
 
 	while (*text == ' ' || *text == '\t')
 		text++;
