@@ -102,7 +102,7 @@ static struct listmenu *find_widget_in_list_menu(
 		for (scan=listmenu; scan; scan=scan->next)
 			if (w == scan->shell)
 				return(scan);
-	while (w = XtParent(w));
+	while ((w = XtParent(w)));
 	return(0);
 }
 
@@ -116,26 +116,26 @@ static struct listmenu *find_widget_in_list_menu(
  */
 
 static struct listmenu *create_list_menu(
-	time_t			time,		/* for what day? */
-	time_t			period,		/* for how many days? */
-	char			*key,		/* keyword lookup? */
-	struct entry		*entry,		/* just this one entry? */
-	int			user_plus_1,	/* which user file */
-	BOOL			private)	/* only private */
+	time_t		time,		/* for what day? */
+	time_t		period,		/* for how many days? */
+	char		*key,		/* keyword lookup? */
+	struct entry	*entry,		/* just this one entry? */
+	int		user_plus_1,	/* which user file */
+	BOOL		private)	/* only private */
 {
-	register struct listmenu *scan;		/* popup scan pointer */
+	struct listmenu *scan;		/* popup scan pointer */
 
 	confirm_new_entry();
 	for (scan=listmenu; scan; scan=scan->next) {	/* similar menu? */
 		if (!scan->valid || !scan->popped)
 			continue;
-		if (time	&& scan->time == time
-				&& scan->period == period		||
-		    key		&& scan->key
-		    		&& !strcmp(scan->key, key)		||
-		    entry	&& entry == scan->oneentry		||
-		    user_plus_1	&& user_plus_1 == scan->user_plus_1	||
-		    private	&& scan->private)
+		if ((time	 && scan->time == time
+				 && scan->period == period)		||
+		    (key	 && scan->key
+		    		 && !strcmp(scan->key, key))		||
+		    (entry	 && entry == scan->oneentry)		||
+		    (user_plus_1 && user_plus_1 == scan->user_plus_1)	||
+		    (private	 && scan->private))
 
 			return(scan);
 	}
@@ -275,7 +275,7 @@ void create_list_popup(
 			strcat(title, mkdatestring(time + period - 1));
 		} else {
 			tm  = time_to_tm(time);
-			if (p = parse_holidays(tm->tm_year, FALSE))
+			if ((p = parse_holidays(tm->tm_year, FALSE)))
 				create_error_popup(mainmenu.cal, 0, p);
 			shp = &sm_holiday[tm->tm_yday];
 			hp  =    &holiday[tm->tm_yday];
@@ -573,8 +573,8 @@ void create_entry_widgets(
 
 	/* need more! */
 	n = (nentries+1) * SC_N * sizeof(Widget *);
-	if (w->entry && !(w->entry = (Widget (*)[])realloc(w->entry, n)) ||
-	   !w->entry && !(w->entry = (Widget (*)[])malloc(n)))
+	if ((w->entry && !(w->entry = (Widget (*)[])realloc(w->entry, n))) ||
+	   (!w->entry && !(w->entry = (Widget (*)[])malloc(n))))
 		fatal(_("no memory"));
 
 	XtUnmanageChild(w->list);
@@ -636,7 +636,7 @@ void create_entry_widgets(
 		}
 		if (!y || x >= SC_L)
 			class = xmLabelWidgetClass;
-		if (x && y && x < SC_L || !y && x >= SC_L)
+		if ((x && y && x < SC_L) || (!y && x >= SC_L))
 			name  = " ";
 		if (!y && class != xmLabelWidgetClass)
 			continue;
@@ -932,8 +932,8 @@ can disable all with the File->File list popup."),
 /*ARGSUSED*/
 static void list_confirm(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (find_widget_in_list_menu(widget) == edit.menu)
 		confirm_new_entry();
@@ -943,8 +943,8 @@ static void list_confirm(
 /*ARGSUSED*/
 static void list_undo(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (lw == edit.menu && prepare_for_modify(edit.entry.user)) {
@@ -957,8 +957,8 @@ static void list_undo(
 /*ARGSUSED*/
 static void list_dup(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct entry tmp;
 	struct listmenu *lw = find_widget_in_list_menu(widget);
@@ -984,8 +984,8 @@ static void list_dup(
 /*ARGSUSED*/
 static void list_delete(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (!edit.editing || lw != edit.menu
@@ -1013,8 +1013,8 @@ static void list_delete(
 /*ARGSUSED*/
 static void list_done(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (lw)
@@ -1024,7 +1024,7 @@ static void list_done(
 /*ARGSUSED*/
 static void list_pin(
 	Widget				widget,
-	int				item,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
@@ -1035,7 +1035,7 @@ static void list_pin(
 /*ARGSUSED*/
 static void list_own(
 	Widget				widget,
-	int				item,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
@@ -1064,8 +1064,8 @@ static void list_entry(
 /*ARGSUSED*/
 static void list_edit(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct listmenu			*lw = find_widget_in_list_menu(widget);
 	char				*text = XmTextGetString(widget);
