@@ -473,9 +473,9 @@ void create_except_popup(void)
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_except_popup();
 }
@@ -487,9 +487,9 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void text_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	readback_except_menu();
 	fillout_except_menu();
@@ -498,9 +498,9 @@ static void text_callback(
 
 /*ARGSUSED*/
 static void clear_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	print_text_button(text_w[item], "");
 	readback_except_menu();
@@ -510,9 +510,9 @@ static void clear_callback(
 
 /*ARGSUSED*/
 static void split_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	char		*string, *p;	/* contents of text widget */
 	time_t		time;		/* exception time to make appt for */
@@ -556,9 +556,9 @@ static void split_callback(
 
 /*ARGSUSED*/
 static void hide_m_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.entry.hide_in_m ^= TRUE;
 	edit.changed = TRUE;
@@ -569,9 +569,9 @@ static void hide_m_callback(
 
 /*ARGSUSED*/
 static void hide_y_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.entry.hide_in_y ^= TRUE;
 	edit.changed = TRUE;
@@ -582,9 +582,9 @@ static void hide_y_callback(
 
 /*ARGSUSED*/
 static void hide_w_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.entry.hide_in_w ^= TRUE;
 	edit.changed = TRUE;
@@ -595,9 +595,9 @@ static void hide_w_callback(
 
 /*ARGSUSED*/
 static void hide_d_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.entry.hide_in_d ^= TRUE;
 	edit.changed = TRUE;
@@ -608,9 +608,9 @@ static void hide_d_callback(
 
 /*ARGSUSED*/
 static void hide_o_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.entry.hide_in_o ^= TRUE;
 	edit.changed = TRUE;
@@ -621,9 +621,9 @@ static void hide_o_callback(
 
 /*ARGSUSED*/
 static void notime_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.entry.notime ^= TRUE;
 	edit.changed = TRUE;
@@ -639,9 +639,9 @@ static void notime_callback(
 
 /*ARGSUSED*/
 static void acol_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit.changed = TRUE;
 #ifdef XmCSimpleOptionMenu
