@@ -123,7 +123,7 @@ BOOL read_mainlist(void)
 		obtain_netplan_users(config.webplan_host ? config.webplan_host
 							 : "localhost");
 	} else {					/* main data */
-		if (error = readfile(&mainlist, DB_PUB_PATH, 0, TRUE))
+		if ((error = readfile(&mainlist, DB_PUB_PATH, 0, TRUE)))
 			sprintf(msg+strlen(msg),
 				_("Failed to read master file %s, error %d\n"),
 				DB_PUB_PATH, error);
@@ -133,7 +133,7 @@ BOOL read_mainlist(void)
 				"data file %s is not writable\n"),DB_PUB_PATH);
 
 							/* private data */
-		if (error = readfile(&mainlist, DB_PRIV_PATH, 0, FALSE))
+		if ((error = readfile(&mainlist, DB_PRIV_PATH, 0, FALSE)))
 			sprintf(msg+strlen(msg),
 				_("Failed to read private file %s, error %d\n"),
 				DB_PRIV_PATH, error);
@@ -144,7 +144,7 @@ BOOL read_mainlist(void)
 
 		make_default_user(resolve_tilde(DB_PUB_PATH));
 	}
-	if (p = attach_to_network())			/* network connection*/
+	if ((p = attach_to_network()))			/* network connection*/
 		strcat(msg, p);
 	read_from_server(&mainlist, 0, 0);
 							/* user data */
@@ -262,7 +262,7 @@ static int readfile(
 		    *line >= '0' && *line <= '9' && user
 						 && user[u].fromserver)
 			break;
-		parse_file_line(list, path, user ? user[u].name:0, conf, line);
+		parse_file_line(list, path, user ? user[u].name:0, line);
 	}
 	if (writable)
 		lockfile(fp, FALSE);
@@ -283,13 +283,12 @@ void parse_file_line(
 	struct plist		**list,		/* list to add to */
 	char			*path,		/* file/server to read from */
 	char			*name,		/* user name, 0=not yet known*/
-	BOOL			conf,		/* if TRUE, config stuff too */
 	char			*line)		/* line to be parsed */
 {
-	register struct config	*c = &config;
+	struct config		*c = &config;
 	int			fid, rid;	/* network file ID and row ID*/
 	char			*instring;	/* string at line[2] or [3] */
-	register char		*p;		/* line scan pointer */
+	char			*p;		/* line scan pointer */
 	static struct entry	entry;		/* temp entry before adding */
 	static struct entry	*ep = 0;	/* list entry being read */
 	int			n, m;		/* tmp entry # of ep in list */
@@ -530,7 +529,7 @@ void parse_file_line(
 			tm.tm_year += 100;
 		if (tm.tm_year > 1900)
 			tm.tm_year -= 1900;
-		if (entry.notime = tm.tm_hour > 23)
+		if ((entry.notime = tm.tm_hour > 23))
 			tm.tm_hour = tm.tm_min = tm.tm_sec = 0;
 		entry.time         = tm_to_time(&tm);
 		entry.length       = tmp[0]*3600 + tmp[1]*60 + tmp[2];
@@ -678,21 +677,21 @@ static void make_default_user(
 
 #ifdef PLANGROK
 static void convert_dbase(
-	struct plist		**list,		/* list to add to */
-	register struct user	*up,		/* user with form/dbase */
-	char			*db)		/* db name for error messages*/
+	struct plist	**list,		/* list to add to */
+	struct user	*up,		/* user with form/dbase */
+	char		*db)		/* db name for error messages*/
 {
-	struct entry		*elist;		/* temporary list of entries */
-	register struct entry	*ep;		/* list entry being read */
-	ITEM			*item;		/* current field description */
-	ROW			*row;		/* curr database row */
-	register char		*data;		/* curr database contents */
-	int			en, ei;		/* # of entries; curr entry */
-	int			fn, fi;		/* # of fields; curr field */
-	BOOL			tagged=FALSE;	/* dbase has plan interface? */
-	BOOL			have_d, have_n;	/* dbase has date & note? */
-	int			def_d, def_n;	/* default date & note fields*/
-	int			n;
+	struct entry	*elist;		/* temporary list of entries */
+	struct entry	*ep;		/* list entry being read */
+	ITEM		*item;		/* current field description */
+	ROW		*row;		/* curr database row */
+	char		*data;		/* curr database contents */
+	int		en, ei;		/* # of entries; curr entry */
+	int		fn, fi;		/* # of fields; curr field */
+	BOOL		tagged=FALSE;	/* dbase has plan interface? */
+	BOOL		have_d, have_n;	/* dbase has date & note? */
+	int		def_d, def_n;	/* default date & note fields*/
+	int		n;
 
 	if ((en = up->dbase->nrows) < 1 || (fn = up->form->nitems) < 1)
 		return;
