@@ -2,7 +2,7 @@
  * write the master list to the ~/.dayplan file.
  *
  *	copyfile(source, target)		Copy a file
- *	write_database(list, path, what)	Write appointments and config
+ *	write_mainlist(list, path, what)	Write appointments and config
  *						info to a database file.
  */
 
@@ -140,20 +140,20 @@ static int write_to_file(line) char *line;
 	  return(errno && errno != ENOTTY); }
 
 static BOOL writefile(
-	struct plist		*list,		/* list to write */
-	char			*path,		/* file to write list to */
-	int			u,		/* user index, 0=own */
-	int			what)		/* bitmap of WR_* macros */
+	struct plist	*list,		/* list to write */
+	char		*path,		/* file to write list to */
+	int		u,		/* user index, 0=own */
+	int		what)		/* bitmap of WR_* macros */
 {
-	register struct config	*c = &config;
-	FILE			*fp;		/* open file */
-	char			backpath[1024];	/* path of backup file */
-	char			line[1024];	/* line buffer */
-	char			*name;		/* name of user, 0=own */
-	register char		*p;		/* string copy pointers */
-	register struct entry	*ep;		/* list entry being written */
-	int			i;		/* entry counter */
-	BOOL			write_error = FALSE;
+	struct config	*c = &config;
+	FILE		*fp;		/* open file */
+	char		backpath[1024];	/* path of backup file */
+	char		line[1024];	/* line buffer */
+	char		*name;		/* name of user, 0=own */
+	char		*p;		/* string copy pointers */
+	struct entry	*ep;		/* list entry being written */
+	int		i;		/* entry counter */
+	BOOL		write_error = FALSE;
 
 	if (user[u].readonly)
 		return(TRUE);
@@ -338,12 +338,12 @@ static BOOL writefile(
 	}
 	name = user ? user[u].name : 0;
 	for (ep=list->entry, i=0; i < list->nentries; i++, ep++) {
-		if (!ep->user && name || ep->user && !name
-				      || ep->user && name
-				      		  && strcmp(ep->user, name))
+		if ((!ep->user &&  name) ||
+		     (ep->user && !name) ||
+		     (ep->user &&  name  && strcmp(ep->user, name)))
 			continue;
-		if (ep->private && !(what & WR_PRIVATE) ||
-		   !ep->private && !(what & WR_PUBLIC))
+		if ((ep->private && !(what & WR_PRIVATE)) ||
+		   (!ep->private && !(what & WR_PUBLIC)))
 			continue;
 
 		curr_fp = fp;
@@ -384,14 +384,14 @@ Could not restore original contents. Backup is in\n\
  */
 
 int write_one_entry(
-	int			(*callback)(),	/* function that writes line */
-	register struct entry	*ep)		/* list entry to write */
+	int		(*callback)(),	/* function that writes line */
+	struct entry	*ep)		/* list entry to write */
 {
-	char			line[10240];	/* line buffer */
-	register char		*p, *q;		/* string copy pointers */
-	int			j;		/* exception counter */
-	struct tm		*tm;		/* time to m/d/y h:m:s conv */
-	BOOL			write_error = FALSE;
+	char		line[10240];	/* line buffer */
+	char		*p, *q;		/* string copy pointers */
+	int		j;		/* exception counter */
+	struct tm	*tm;		/* time to m/d/y h:m:s conv */
+	BOOL		write_error = FALSE;
 
 	tm = time_to_tm(ep->time);
 	sprintf(line,
@@ -446,10 +446,11 @@ int write_one_entry(
 
 	for (j=0; j < 4; j++) {
 		switch(j) {
-		  case 0: p=ep->note;	 break;
-		  case 1: p=ep->message; break;
-		  case 2: p=ep->script;	 break;
-		  case 3: p=ep->java;	 break;
+		  case 0:  p = ep->note;	break;
+		  case 1:  p = ep->message;	break;
+		  case 2:  p = ep->script;	break;
+		  case 3:  p = ep->java;	break;
+		  default: p = 0;
 		}
 		if (p)
 			while (*p) {
