@@ -64,12 +64,12 @@ static void broken_pipe_handler(int sig)
 static BOOL writefile(DBASE *, FORM *, int);
 
 BOOL write_dbase(
-	DBASE			*dbase,		/* form and items to write */
-	FORM			*form,		/* contains column delimiter */
-	BOOL			force)		/* write even if not modified*/
+	DBASE		*dbase,		/* form and items to write */
+	FORM		*form,		/* contains column delimiter */
+	BOOL		force)		/* write even if not modified*/
 {
-	int			s;		/* section index */
-	BOOL			ok = TRUE;
+	int		s;		/* section index */
+	BOOL		ok = TRUE;
 
 	if (dbase->nsects == 1 && (dbase->modified || force))
 		ok = writefile(dbase, form, 0);
@@ -83,20 +83,20 @@ BOOL write_dbase(
 
 
 static BOOL writefile(
-	DBASE			*dbase,		/* form and items to write */
-	FORM			*form,		/* contains column delimiter */
-	int			nsect)		/* section to write */
+	DBASE		*dbase,		/* form and items to write */
+	FORM		*form,		/* contains column delimiter */
+	int		nsect)		/* section to write */
 {
-	SECTION			*sect;		/* section to write */
-	char			*path;		/* file to write list to */
-	FILE			*fp;		/* open file */
-	int			r, c;		/* row and column counters */
-	int			hicol;		/* # of columns of card -1 */
-	char			*value;		/* converted data to write */
-	char			buf[40];	/* for date/time conversion */
-	register ITEM		*item;		/* item describing value */
-	register int		i;		/* index of item */
-	register char		*p;		/* string copy pointer */
+	SECTION		*sect;		/* section to write */
+	char		*path;		/* file to write list to */
+	FILE		*fp;		/* open file */
+	int		r, c;		/* row and column counters */
+	int		hicol;		/* # of columns of card -1 */
+	char		*value;		/* converted data to write */
+	char		buf[40];	/* for date/time conversion */
+	ITEM		*item = 0;	/* item describing value */
+	int		i;		/* index of item */
+	char		*p;		/* string copy pointer */
 
 	sect = &dbase->sect[nsect];
 	path = sect->path ? sect->path : form->dbase;
@@ -127,7 +127,7 @@ static BOOL writefile(
 			if (dbase_get(dbase, r, hicol))
 				break;
 		for (c=0; c <= hicol; c++) {
-			if (value = dbase_get(dbase, r, c)) {
+			if ((value = dbase_get(dbase, r, c))) {
 				for (i=form->nitems-1; i >= 0; i--) {
 					item = form->items[i];
 					if (item->column == c)
@@ -225,7 +225,7 @@ BOOL read_dbase(
 	if (*path != '/' && *path != '~' && form->path) {
 		char *p;
 		strcpy(pathbuf, form->path);
-		if (p = strrchr(pathbuf, '/')) {
+		if ((p = strrchr(pathbuf, '/'))) {
 			strcpy(p+1, path);
 			path = pathbuf;
 		}
@@ -245,12 +245,12 @@ BOOL read_dbase(
  */
 
 static BOOL find_db_file(
-	DBASE			*dbase,		/* form and items to write */
-	FORM			*form,		/* contains column delimiter */
-	char			*path)		/* file to read list from */
+	DBASE		*dbase,		/* form and items to write */
+	FORM		*form,		/* contains column delimiter */
+	char		*path)		/* file to read list from */
 {
-	char			pathbuf[1024];	/* file name with path */
-	int			nread = 0;	/* # of successful reads */
+	char		pathbuf[1024];	/* file name with path */
+	int		nread = 0;	/* # of successful reads */
 
 	sprintf(pathbuf, "%s.db", path);
 	if (!access(pathbuf, F_OK))
@@ -268,24 +268,24 @@ static BOOL find_db_file(
 #define MAXSC  1000		/* no more than 200 sections */
 
 static int compare_name(
-	register MYCONST void	*u,
-	register MYCONST void	*v)
+	MYCONST void	*u,
+	MYCONST void	*v)
 {
 	return(strcmp(*(char **)u, *(char **)v));
 }
 
 static BOOL read_dir_or_file(
-	DBASE			*dbase,		/* form and items to write */
-	FORM			*form,		/* contains column delimiter */
-	char			*path)		/* file to read list from */
+	DBASE		*dbase,		/* form and items to write */
+	FORM		*form,		/* contains column delimiter */
+	char		*path)		/* file to read list from */
 {
-	char			*name[MAXSC];	/* directory listing */
-	char			pathbuf[1024];	/* file name with path */
-	struct stat		statbuf;	/* is path a directory? */
-	DIR			*dir;		/* open directory file */
-	struct dirent		*dp;		/* one directory entry */
-	int			nfiles = 0;	/* # of files in directory */
-	int			i, n=0;
+	char		*name[MAXSC];	/* directory listing */
+	char		pathbuf[1024];	/* file name with path */
+	struct stat	statbuf;	/* is path a directory? */
+	DIR		*dir;		/* open directory file */
+	struct dirent	*dp;		/* one directory entry */
+	int		nfiles = 0;	/* # of files in directory */
+	int		i, n=0;
 
 	if (stat(path, &statbuf))
 		return(FALSE);
@@ -315,23 +315,23 @@ static BOOL read_dir_or_file(
  */
 
 static BOOL read_file(
-	DBASE			*dbase,		/* form and items to write */
-	FORM			*form,		/* contains column delimiter */
-	char			*path,		/* file to read list from */
-	time_t			mtime)		/* file modification time */
+	DBASE		*dbase,		/* form and items to write */
+	FORM		*form,		/* contains column delimiter */
+	char		*path,		/* file to read list from */
+	time_t		mtime)		/* file modification time */
 {
-	SECTION			*sect;		/* new section */
-	FILE			*fp;		/* open file */
-	int			nc = 0;		/* size of curr line */
-	int			col = 0;	/* current column being added*/
-	int			row = -1;	/* current row being added */
-	register char		*buf, *p;	/* buffer for one item */
-	register int		bindex = 0;	/* next free byte in buf */
-	int			bsize;		/* size of buf in bytes */
-	char			c, c0;		/* next char from file */
-	BOOL			error;		/* in TRUE, abort */
-	ITEM			*item;		/* for time/date conversion */
-	int			i;
+	SECTION		*sect;		/* new section */
+	FILE		*fp;		/* open file */
+	int		nc = 0;		/* size of curr line */
+	int		col = 0;	/* current column being added*/
+	int		row = -1;	/* current row being added */
+	char		*buf, *p;	/* buffer for one item */
+	int		bindex = 0;	/* next free byte in buf */
+	int		bsize;		/* size of buf in bytes */
+	char		c, c0;		/* next char from file */
+	BOOL		error;		/* in TRUE, abort */
+	ITEM		*item=0;	/* for time/date conversion */
+	int		i;
 
 							/* step 1: open file */
 	signal(SIGPIPE, broken_pipe_handler);
