@@ -9,7 +9,7 @@
  *	register_X_input(fd)		network.c opened new server socket
  *	unregister_X_input(fd)		network.c closed server socket
  *
- * Author: thomas@bitrot.in-berlin.de (Thomas Driemeyer)
+ * Author: thomas@bitrot.de (Thomas Driemeyer)
  */
 
 #include <stdio.h>
@@ -199,6 +199,12 @@ int main(
 				if (argv[n+1] && *argv[n+1] != '-')
 					config.webplan_host = argv[++n];
 				break;
+			  case 'V':
+				create_list(&mainlist);
+				read_mainlist();
+				write_vcal_mainlist(argv[n+1] ? argv[n+1]
+							      : "vcal");
+				return(0);
 			  case 'F':
 				_exit(!dumpfilelist());
 			  case 'H':
@@ -281,11 +287,11 @@ int main(
 	(void)recycle_all(mainlist, config.autodel, 0);
 	signal(SIGHUP, sighand);
 
-	if (!startup_lock(resolve_tilde(PLANLOCK), nolock))
+	if (!startup_lock(FALSE, nolock))
 		if (!all_files_served())
 			create_multiple_popup(nolock);
 							/* holidays ok? */
-	if (errmsg = parse_holidays(curr_year, TRUE))
+	if ((errmsg = parse_holidays(curr_year, TRUE)))
 		create_error_popup(mainmenu.cal, 0, errmsg);
 							/* start */
 #if !defined(SUN) && !defined(IBM)
@@ -444,7 +450,7 @@ static void non_interactive(
 				    mktimestring(trigger, FALSE), msg);
 	fflush(stdout);
 	sprintf(lockfile, resolve_tilde(PLANLOCK), (int)getuid());
-	if (fp = fopen(lockfile, "r")) {
+	if ((fp = fopen(lockfile, "r"))) {
 		fscanf(fp, "%d", &pid);
 		if (pid > 1)
 			(void)kill(pid, SIGHUP);
@@ -491,8 +497,8 @@ static int dumptoday(
 		for (i=0; i < NEXC; i++)
 			if (ep->except[i] == trigger)
 				break;
-		if (i < NEXC || ep->suspended || !ulist && !others &&
-				(ep->user && strcmp(ep->user, user[0].name)))
+		if (i < NEXC || ep->suspended || (!ulist && !others &&
+				(ep->user && strcmp(ep->user, user[0].name))))
 			continue;
 		if (ulist) {
 			char *ul = mystrdup(ulist), *u;
@@ -638,7 +644,7 @@ static void usage(void)
 	    "\t-c N\t\tcolor code for appointment\n",
 	    "\t-h [m|y|w|o|d]*\thide in month, year, week, overview or day views\n");
 	fprintf(stderr,
-	    "batch usage: %s options\n\tOptions:\n%s%s%s%s%s%s%s%s%s%s%s%s",
+	    "batch usage: %s options\n\tOptions:\n%s%s%s%s%s%s%s%s%s%s%s%s%s",
 	    progname,
 	    "\t-h\t\tprint this help text\n",
 	    "\t-d\t\tdump fallback app-defaults and exit\n",
@@ -651,7 +657,8 @@ static void usage(void)
 	    "\t\t\teg: -t, -t +3, -T tomorrow, -o -t 24.12. 3, -o -T wed 7\n",
 	    "\t-o\t\tmodifies -t/-T output to show other users\n",
 	    "\t-u N\t\tmodifies -t/-T to show comma-separated user list N\n",
-	    "\t-i\t\tmake -t/-T machine-readable (used by WWW frontend)\n");
+	    "\t-i\t\tmake -t/-T machine-readable (used by WWW frontend)\n",
+	    "\t-V file\t\texperimental vCalendar export\n");
 	exit(1);
 }
 
@@ -717,8 +724,8 @@ void do_get_rsrc(
 
 static void init_resources(void)
 {
-	register struct config	*c = &config;
-	char			*startup_as = 0;
+	struct config	*c = &config;
+	char		*startup_as = 0;
 
 	get_rsrc(&c->calbox_xs[0],   "calBoxWidth",    "CalBoxWidth",  XtRInt);
 	get_rsrc(&c->calbox_ys[0],   "calBoxHeight",   "CalBoxHeight", XtRInt);
@@ -985,8 +992,8 @@ void resynchronize_daemon(void)
 
 /*ARGSUSED*/
 static void timer_callback(
-	XtPointer	data,		/* not used */
-	XtIntervalId	*id)		/* not used */
+	UNUSED XtPointer    data,	/* not used */
+	UNUSED XtIntervalId *id)	/* not used */
 {
 	static int	busy;		/* this code is not reentrant */
 	static time_t	last_tod;	/* previous time-of-day */
@@ -1054,8 +1061,8 @@ static void sig_check_timer (
 
 #if !defined(SUN) && !defined(IBM)
 static void sig_callback (
-	XtPointer	data,		/* closure */
-	XtSignalId	*id)
+	UNUSED XtPointer  data,		/* closure */
+	UNUSED XtSignalId *id)
 {
 	if (last_x_timer < get_time()-30)	/* Even if last_x_timer == -1*/
 		timer_callback(0, 0);
@@ -1073,12 +1080,12 @@ static void sig_callback (
  */
 
 static void socket_callback(
-	XtPointer	data,
-	int		*fd,
-	XtInputId	*x_id)
+	UNUSED XtPointer data,
+	int		 *fd,
+	UNUSED XtInputId *x_id)
 {
-	char		buf[1024];	/* message buffer for gets_server */
-	BOOL		save_mod;	/* auto-update isn't a modification */
+	char		 buf[1024];	/* message buffer for gets_server */
+	BOOL		 save_mod;	/* auto-update isn't a modification */
 
 	save_mod = mainlist->modified;
 	(void)gets_server(*fd, buf, sizeof(buf), FALSE, FALSE);
