@@ -82,7 +82,7 @@ MOUSE locate_in_month_calendar(
 	struct entry	**epp,		/* returned entry or 0 */
 	BOOL		*warn,		/* is *epp an n-days-ahead w?*/
 	time_t		*time,		/* if *epp=0, clicked where */
-	time_t		*trigger,	/* if *epp=0, entry trigger */
+	UNUSED time_t	*trigger,	/* if *epp=0, entry trigger */
 	int		*xp,		/* if M_INSIDE, rubber box position */
 	int		*yp,
 	int		*xsp,		/* and size */
@@ -90,7 +90,7 @@ MOUSE locate_in_month_calendar(
 	int		xc,		/* pixel pos clicked */
 	int		yc)
 {
-	register struct config	*c = &config;
+	struct config	*c = &config;
 	int		xd, yd;		/* top left of clicked day box */
 	int		day, n;		/* clicked day number, note line */
 	struct tm	tm;		/* for pos->time_t conversion */
@@ -136,7 +136,7 @@ MOUSE locate_in_month_calendar(
 		*warn = FALSE;
 	if (epp)
 		*epp = 0;
-	if (*time = date_to_time(day, curr_month, curr_year, 0, 0, 0)) {
+	if ((*time = date_to_time(day, curr_month, curr_year, 0, 0, 0))) {
 		int day_xs = c->calbox_xs[sm];
 		int yo = font[FONT_DAY+sm]->max_bounds.ascent;
 		xd  = c->calbox_marg[sm] + c->calbox_arrow[sm] + xd * day_xs;
@@ -175,14 +175,14 @@ void draw_month_year(void)
  */
 
 void draw_calendar(
-	Region			region)
+	Region		region)
 {
-	register struct config	*c = &config;
-	Window			window;
-	XRectangle		rects[7+8], *r = rects;
-	XPoint			point[4];
-	int			i, j, x, y;
-	int			sm = c->smallmonth;
+	struct config	*c = &config;
+	Window		window;
+	XRectangle	rects[7+8], *r = rects;
+	XPoint		point[4];
+	int		i, j, x, y;
+	int		sm = c->smallmonth;
 
 	if (!mainmenu.cal) {
 		if (region)
@@ -346,7 +346,7 @@ void draw_day(
 	sprintf(buf, "%d", day);
 	XSetFont(display, gc, font[FONT_DAY+sm]->fid);
 
-	if (errmsg = parse_holidays(curr_year, FALSE))
+	if ((errmsg = parse_holidays(curr_year, FALSE)))
 		create_error_popup(mainmenu.cal, 0, errmsg);
 	jul = monthbegin[curr_month] + day-1 +(curr_month>1 && !(curr_year&3));
 	hp  =    &holiday[jul];
@@ -367,13 +367,14 @@ void draw_day(
 		(void)date_to_time(day, curr_month, curr_year,
 						&wkday, &jul, &weeknum);
 		*buf = 0;
-		if (config.weeknum && leftedge)
+		if (config.weeknum && leftedge) {
 			if (config.gpsweek)
-				sprintf(buf, "[%d]", (curr_year * 365
+				sprintf(buf, "[%d]", ((curr_year * 365
 						+ (curr_year+3)/4
-						+ jul) / 7 + 945 & 1023);
+						+ jul) / 7 + 945) & 1023);
 			else
 				sprintf(buf, "(%d)", weeknum+1);
+		}
 		if (config.julian)
 			sprintf(buf+strlen(buf), "%d", jul+1);
 		truncate_string(buf, config.calbox_xs[sm] - 3 - daynum_xs,
@@ -386,7 +387,7 @@ void draw_day(
 
 	}
 							/* small holiday */
-	if (shp->string && (!config.julian && !config.weeknum ||
+	if (shp->string && ((!config.julian && !config.weeknum) ||
 				font[FONT_DAY+sm]->max_bounds.ascent >=
 				font[FONT_NOTE]->max_bounds.ascent * 2 - 1)) {
 		strncpy(buf, shp->string, sizeof(buf)-1);
@@ -437,33 +438,33 @@ void draw_day(
  */
 
 static void draw_day_notes(
-	int			day)		/* 1..31 */
+	int		day)		/* 1..31 */
 {
-	BOOL			today;		/* TRUE: it's today's daybox */
-	struct tm		*tm;		/* for daylight-saving tzone */
-	time_t			tod;		/* current time-of-day */
-	time_t			daytime;	/* time of day box, in sec */
-	BOOL			found;		/* TRUE if lookup succeeded */
-	BOOL			othermonth;	/* not current month ? */
-	int			tmp_curr_month;	/* tmp storage for curr_month*/
-	int			tmp_curr_year;	/* tmp storage for curr_year */
-	int			last_day;	/* last day of current month */
-	struct lookup		lookup;		/* result of entry lookup */
-	register struct entry	*ep;		/* ptr to entry in mainlist */
-	int			u;		/* if other user, user[] indx*/
-	int			x, y;		/* position in calendar */
-	int			xo, i;		/* for aligning ':' in time */
-	int			ye;		/* bottom limit of day box */
-	int			ys;		/* height of a text line */
-	char			buf[100];	/* string buffer (time/note) */
-	int			jul;		/* julian date of daybox */
-	int			nlines = 0;	/* # printed, <lines_per_day */
-	struct holiday		*hp;		/* holiday info for this day */
-	char			*errmsg;	/* parser error */
-	Window			window;
-	int			sm = config.smallmonth;
-	int			ascent, descent;
-	struct entry		**drawn_entry = 0;
+	BOOL		today;		/* TRUE: it's today's daybox */
+	struct tm	*tm;		/* for daylight-saving tzone */
+	time_t		tod;		/* current time-of-day */
+	time_t		daytime;	/* time of day box, in sec */
+	BOOL		found;		/* TRUE if lookup succeeded */
+	BOOL		othermonth;	/* not current month ? */
+	int		tmp_curr_month;	/* tmp storage for curr_month*/
+	int		tmp_curr_year;	/* tmp storage for curr_year */
+	int		last_day;	/* last day of current month */
+	struct lookup	lookup;		/* result of entry lookup */
+	struct entry	*ep;		/* ptr to entry in mainlist */
+	int		u;		/* if other user, user[] indx*/
+	int		x, y;		/* position in calendar */
+	int		xo, i;		/* for aligning ':' in time */
+	int		ye;		/* bottom limit of day box */
+	int		ys;		/* height of a text line */
+	char		buf[100];	/* string buffer (time/note) */
+	int		jul;		/* julian date of daybox */
+	int		nlines = 0;	/* # printed, <lines_per_day */
+	struct holiday	*hp;		/* holiday info for this day */
+	char		*errmsg;	/* parser error */
+	Window		window;
+	int		sm = config.smallmonth;
+	int		ascent, descent;
+	struct entry	**drawn_entry = 0;
 
 	if (!mainmenu.cal)
 		return;
@@ -541,7 +542,7 @@ static void draw_day_notes(
 	XFillRectangle(display, window, gc, x,y, config.calbox_xs[sm]-3, ye-y);
 
 							/* large holiday? */
-	if (errmsg = parse_holidays(curr_year, FALSE))
+	if ((errmsg = parse_holidays(curr_year, FALSE)))
 		create_error_popup(mainmenu.cal, 0, errmsg);
 	jul = monthbegin[curr_month] +day-1 + (curr_month>1 && !(curr_year&3));
 	hp  = &holiday[jul];
