@@ -11,6 +11,8 @@ typedef void *Widget;	/* dummy for prototype declarations in config.h */
 #include <stdarg.h>
 #include <time.h>
 #include <limits.h>
+#include <syslog.h>
+#include <pwd.h>
 #include <sys/types.h>
 #include <dirent.h>
 #include <errno.h>
@@ -40,11 +42,12 @@ typedef void *Widget;	/* dummy for prototype declarations in config.h */
 
 #define ACLCHKINTER 60          /* interval (secs) for check of the acl file */
 
-static char		*progname;	/* name of this program, argv[0] */
+char			*progname;	/* name of this program, argv[0] */
 static BOOL		debug;		/* foreground, logging is enabled */
 static BOOL		foregnd;	/* foreground without logging */
 BOOL			verbose;	/* debug mode, don't daemonize */
-static BOOL		allow_all = FALSE; /* no access list, never deny */
+BOOL			to_syslog;	/* print to syslog, not stderr */
+static BOOL		allow_all;	/* no access list, never deny */
 static int		nclients;	/* size of array */
 static unsigned int	row_id = 1;	/* next available row ID */
 static int		max_files;	/* size of file_list array */
@@ -52,7 +55,7 @@ static struct pfile	*file_list;	/* array of open files */
 struct client		*client_list;	/* array of clients (entry 0 unused) */
 static fd_set		rd0, wr0, ex0;	/* preset fd masks for main select */
 static time_t		update_time;	/* date of last unwritten change */
-static BOOL             do_auth = FALSE;/* authentication required (identd) */
+static BOOL             do_auth;	/* authentication required (identd) */
 static int		netplan_port[2];/* ports we are listening on */
 static int		fd_inet[2];	/* file descriptor for base socket */
 
@@ -65,9 +68,9 @@ static void eval_message(int, char *);
 static void appendbuf(struct buffer *, char *, int);
 static void notify_client(int, unsigned int, int);
 static void close_client(int);
-static BOOL check_file(FILE *, char *, int, struct client *);
+static BOOL check_file(FILE *, char *, int);
 static int  open_file(char *, int, BOOL *);
-static void close_file(int, int, struct client *);
+static void close_file(int, int);
 static void write_file(int);
 static int  find_row(int, unsigned int, BOOL *);
 static unsigned int add_row(int, unsigned int, int, char *, int);
@@ -75,14 +78,14 @@ static void delete_row(int, unsigned int, int);
 static BOOL lock_row(int, unsigned int, int, BOOL);
 static void send_row(int, unsigned int, int, char);
 static int count_rows(int, int);
-static void reply(int, struct client *, char *, ...);
+static void reply(int, char *, ...);
 static void error(int, char *, ...);
 static void fatal(char *, ...);
-char *ip_addr(register struct sockaddr_in *);
+char *ip_addr(struct sockaddr_in *);
 static void setup_gids(struct client *, int, char *);
 static char *make_descr (struct client *, const char *username,
 			 const char *arg);
-void log(char *, ...);
+void logger(char *, ...);
 
 void *allocate(int n)
 	{void *p = malloc(n); if (!p) fatal("no memory"); return(p);}
@@ -133,27 +136,48 @@ int main(
 	time_t          t;
 	struct stat     st;
 	static const char nobody[] = "anonymous";
-                                        /* descriptive name of unknown users */
+	static const char nobody_name1[] = "netplan";
+	static const char nobody_name2[] = "nobody";
+	uid_t		nobody_uid = NOBODY_UID;
+	gid_t		nobody_gid = NOBODY_GID;
+	struct passwd	*pwent;
 
 	progname = argv[0];				/* cmd line options */
-	while ((c = getopt(argc, argv, "advf")) != EOF)
+	while ((c = getopt(argc, argv, "advfs")) != EOF)
 		switch(c) {
-		  case 'a': do_auth = TRUE;	break;
-		  case 'v': verbose = TRUE;	break;
-		  case 'd': debug   = TRUE;	break;
-		  case 'f': foregnd = TRUE;	break;
-		  default:  fatal("usage: %s [-f] [-d [-v]] [-a]\n"
-				  "-f=foreground, -d=debug, -v=verbose "
-				  "-a=authentication via identd required",
-				  progname);
+		  case 'a': do_auth   = TRUE;	break;
+		  case 'v': verbose   = TRUE;	break;
+		  case 'd': debug     = TRUE;	break;
+		  case 'f': foregnd   = TRUE;	break;
+		  case 's': to_syslog = TRUE;	break;
+		  default:  fprintf(stderr,
+		  		"usage: %s [-f] [-d [-v]] [-a] [-s]\n"
+				"-f   stay in foreground\n"
+				"-d   debug\n"
+				"-v   verbose\n"
+				"-a   authentication via identd required\n"
+				"-s   messages to syslog\n", progname);
+			    _exit(1);
 		}
 
 	t = time(0);
-	log("netplan version %s starting at %s", DVERSION, ctime(&t));
-	log("database directory is %.200s/%.200s\n", HOMEDIR, NETDIR);
+	logger("netplan version %s starting at %s", DVERSION, ctime(&t));
+	logger("database directory is %.200s/%.200s\n", HOMEDIR, NETDIR);
 
-	if (NOBODY_UID == 0 || NOBODY_GID == 0)
-		fatal("netplan compiled with nobody == root");
+	if ((pwent = getpwnam(nobody_name1))) {
+		nobody_uid = pwent->pw_uid;
+		nobody_gid = pwent->pw_gid;
+		logger("user \"%s\" is uid %d gid %d\n",
+			nobody_name1, nobody_uid, nobody_gid);
+
+	} else if ((pwent = getpwnam(nobody_name2))) {
+		nobody_uid = pwent->pw_uid;
+		nobody_gid = pwent->pw_gid;
+		logger("user \"%s\" is uid %d gid %d\n",
+			nobody_name2, nobody_uid, nobody_gid);
+	}
+	if (nobody_uid == 0 || nobody_gid == 0)
+		fatal("netplan refuses to run as root");
 #ifndef __hpux
 #ifdef SETREUID
 	if (getuid() == 0 || geteuid() != 0)
@@ -168,28 +192,28 @@ int main(
 #endif
 #endif
 	if (getuid() == 0 || geteuid() == 0) {
-		log("switching from user <root> to <uid %d gid %d>\n",
-						NOBODY_UID, NOBODY_GID);
+		logger("switching from user <root> to <uid %d gid %d>\n",
+						nobody_uid, nobody_gid);
 #ifndef __hpux
 #ifdef SETREUID
-		setregid(NOBODY_GID, NOBODY_GID);
+		setregid(nobody_gid, nobody_gid);
 #else
-		setgid(NOBODY_GID);
-		setegid(NOBODY_GID);
+		setgid(nobody_gid);
+		setegid(nobody_gid);
 #endif
 #else
-		setgid(NOBODY_GID);
+		setgid(nobody_gid);
 #endif
 
 #ifndef __hpux
 #ifdef SETREUID
-		setreuid(NOBODY_UID, NOBODY_UID);
+		setreuid(nobody_uid, nobody_uid);
 #else
-		setuid(NOBODY_UID);
-		seteuid(NOBODY_UID);
+		setuid(nobody_uid);
+		seteuid(nobody_uid);
 #endif
 #else
-		setuid(NOBODY_UID);
+		setuid(nobody_uid);
 #endif
 	}
 	if (getgid() == 0 || getegid() == 0)
@@ -197,11 +221,17 @@ int main(
 	if (getuid() == 0 || geteuid() == 0)
 		fatal("refusing to run as root");
 
-	log("running with uid=%d gid=%d euid=%d egid=%d\n",
+	logger("running with uid=%d gid=%d euid=%d egid=%d\n",
 				getuid(), getgid(), geteuid(), getegid());
 	if (access(homepath, R_OK | W_OK | X_OK)) {
-		fprintf(stderr, "%s: no read/write access to ", argv[0]);
-		perror(homepath);
+		if (to_syslog)
+			syslog(LOG_ERR, "%s: no read/write access to %s",
+					argv[0], homepath);
+		else {
+			fprintf(stderr, "%s: no read/write access to ",
+					argv[0]);
+			perror(homepath);
+		}
 		_exit(1);
 	}
 	if (!debug && !foregnd) {
@@ -210,7 +240,7 @@ int main(
 		setgid(getgid());
 		switch(fork()) {
 		  case -1:				/* error */
-			log("cannot fork\n");
+			logger("cannot fork\n");
 			break;
 		  case 0:				/* child */
 			ORPHANIZE;
@@ -224,12 +254,13 @@ int main(
 	last_acl_check = time(NULL);
 	if (!stat(aclpath, &st))
 		acl_mod_time = st.st_mtime;
-	log("reading access list file %.200s\n", aclpath);
+	logger("reading access list file %.200s\n", aclpath);
 	if (!acl_read(aclpath)) {
 		if (do_auth)
-			log("cannot read %.200s, allowing NOTHING\n", aclpath);
+			logger("cannot read %.200s, allowing NOTHING\n",
+								aclpath);
 		else {
-			log("cannot read %.200s, allowing everything\n",
+			logger("cannot read %.200s, allowing everything\n",
 								aclpath);
 			allow_all = TRUE;
 		}
@@ -256,7 +287,7 @@ int main(
 		n = select(nclients, &rd, &wr, &ex, update_time ? &timeout :0);
 
 		if (update_time && update_time + 10 < time(0)) {
-			log("writing all modified files to disk\n");
+			logger("writing all modified files to disk\n");
 			for (fd=0; fd < max_files; fd++)
 				write_file(fd);
 			update_time = 0;
@@ -268,15 +299,15 @@ int main(
 			last_acl_check = t;
 			if (st.st_mtime > acl_mod_time) {
 				acl_mod_time = st.st_mtime;
-				log("rereading acl file\n");
+				logger("rereading acl file\n");
 				acl_exit();
 				if (!acl_read(aclpath))
 					if (allow_all)
-						log("cannot read %.200s, "
+						logger("cannot read %.200s, "
 						    "allowing everything\n",
 						    aclpath);
 					else
-						log("cannot read %.200s, "
+						logger("cannot read %.200s, "
 						    "allowing NOTHING\n",
 						    aclpath);
 				else
@@ -298,17 +329,17 @@ int main(
 
 				memset(cp, 0, sizeof(struct client));
 				memcpy(&cp->addr, &addr, n);
-				cp->uid     = NOBODY_UID;
-				cp->gids[0] = NOBODY_GID;
+				cp->uid     = nobody_uid;
+				cp->gids[0] = nobody_gid;
 				cp->descr   = mystrdup(nobody);
 				cp->user    = mystrdup(nobody);
 				cp->port    = netplan_port[c];
 				for (i=1; i < NGROUPS_MAX; i++)
 					cp->gids[i] = -1;
 
-				log("client %d (%.200s) connected from %s\n",
-						fd, cp->descr, ip_addr(&addr));
-				reply(fd, cp,"!t%s enter ? for help",DVERSION);
+				logger("client %d (%.200s) connected from %s\n"
+					       ,fd, cp->descr, ip_addr(&addr));
+				reply(fd, "!t%s enter ? for help", DVERSION);
 				cp->time = time(0);
 			}
 		for (fd=0; fd < nclients; fd++) {
@@ -316,17 +347,17 @@ int main(
 				continue;
 			if (FD_ISSET(fd, &rd))			/* recv cmd */
 				if (!message(fd)) {
-					log("client %d disconnected\n", fd);
+					logger("client %d disconnected\n", fd);
 					close_client(fd);
 					FD_CLR(fd, &rd0);
 					close(fd);
 				}
 			if (FD_ISSET(fd, &wr)) {		/* send reply*/
-				register struct buffer *b;
+				struct buffer *b;
 				b = &client_list[fd].out;
 				n = write(fd, b->data+b->deq, b->enq-b->deq);
 				if (n < 0)
-					log("client %d write fail (%s)\n",
+					logger("client %d write fail (%s)\n",
 							fd, strerror(errno));
 				b->deq += n;
 				if (b->deq == b->enq || n < 0) {
@@ -352,7 +383,7 @@ void exit(
 
 	if (!exiting) {
 		exiting = TRUE;
-		log("exiting, writing all modified files to disk\n");
+		logger("exiting, writing all modified files to disk\n");
 		for (n=0; n < max_files; n++)
 			write_file(n);
 		update_time = 0;
@@ -376,7 +407,7 @@ static void setup_gids(
 
 	cp->gids[ngroups++] = gid;
 	setgrent();
-	while (gr = getgrent())
+	while ((gr = getgrent()))
 		for (p=gr->gr_mem; *p; p++)
 			if (!strcmp(user, *p)) {
 				if (ngroups < NGROUPS_MAX)
@@ -385,7 +416,7 @@ static void setup_gids(
 				break;
 			}
 	if (ngroups > NGROUPS_MAX)
-		log("too many groups (%d, used %d)\n", ngroups, NGROUPS_MAX);
+		logger("too many groups (%d, used %d)\n", ngroups,NGROUPS_MAX);
 }
 
 
@@ -410,7 +441,7 @@ static char *make_descr(
 		hostname = h->h_name;
 	p = buf;
 	if (start_id) {
-		register int n = start_id - arg + 1;
+		int n = start_id - arg + 1;
 		if (n > 40) n = 40;
 		strncpy (p, arg, n);
 		p += n;
@@ -445,8 +476,8 @@ static void init_inet_port(void)
 	struct servent		*serv;
 
 	if (!(serv = getservbyname("netplan", "tcp")))
-		log("netplan/tcp not found in /etc/services, using ports %d "
-						"and %d\n", PORT, OLDPORT);
+		logger("netplan/tcp not found in /etc/services, using ports %d"
+						" and %d\n", PORT, OLDPORT);
 	netplan_port[0] = netplan_port[1] = 0;
 	fd_inet[0] = fd_inet[1] = -1;
 	for (i=0; i < 2; i++) {
@@ -493,7 +524,7 @@ static void close_client(
 	int		fid;
 
 	for (fid=0; fid < max_files; fid++)
-		close_file(fid, fd, c);
+		close_file(fid, fd);
 	release(c->descr);
 	release(c->user);
 	release(c->in.data);
@@ -521,9 +552,9 @@ static void close_client(
 static BOOL message(
 	int		fd)
 {
-	register struct client *c = &client_list[fd];
-	register char	*p, *q;		/* for eliminating \r and \\n->\n */
-	register int	n;		/* number of bytes read from socket */
+	struct client	*c = &client_list[fd];
+	char		*p, *q;		/* for eliminating \r and \\n->\n */
+	int		n;		/* number of bytes read from socket */
 	char		buf[1026];	/* temp incoming message buffer */
 	char		*begin;		/* first un-evaluated byte in buf */
 	fd_set		rd, wr, ex;	/* returned fd masks from select */
@@ -577,11 +608,11 @@ static BOOL message(
 
 static void eval_message(
 	int		fd,		/* client that sent message */
-	register char	*arg)		/* command and argument scan ptr */
+	char		*arg)		/* command and argument scan ptr */
 {
-	register struct client *c = &client_list[fd];
-	register char	*p;		/* for eliminating \r and \\n->\n */
-	register int	n, i;		/* number of bytes read from socket */
+	struct client	*c = &client_list[fd];
+	char		*p;		/* for eliminating \r and \\n->\n */
+	int		n, i;		/* number of bytes read from socket */
 	int		fid;		/* file ID argument */
 	BOOL            ronly;          /* read-only flag */
 	unsigned int	rid;		/* row ID argument */
@@ -598,7 +629,7 @@ static void eval_message(
 		"modified" };
 
 	if (verbose)
-		log("client %d sends %.400s", fd, arg);
+		logger("client %d sends %.400s\n", fd, arg);
 	switch(*arg++) {
 	  case '\n':
 		break;
@@ -624,30 +655,31 @@ static void eval_message(
 					p += strlen(p);
 				}
 				strcpy(p, "\n");
-				log(buf);
+				logger(buf);
 			} else {
 				c->auth_fail = TRUE;
 				error(fd, "Unable to verify your identity "
 						"using identd,\\\nonly public "
 						"files will be accessible.");
-				log("client %d: identd authentication failed\n"
-						,fd);
+				logger("client %d: identd authentication "
+						"failed\n", fd);
 			}
 			release(id);
 		} else {
 			release(c->descr);
 			c->descr = mystrdup(arg);
 			c->auth_fail = FALSE;
-			if (p = strstr(arg, "uid=")) {
+			if ((p = strstr(arg, "uid="))) {
 				c->uid = atoi(p+4);
-				if (pw = getpwuid(c->uid)) {
+				if ((pw = getpwuid(c->uid))) {
 					release(c->user);
 					c->user = mystrdup(pw->pw_name);
 					setup_gids(c, pw->pw_gid, pw->pw_name);
 				} else
-					log("client %d: WARNING: unknown uid "
-						"%d, owner and group ACLs will"
-						" be ineffective\n",fd,c->uid);
+					logger("client %d: WARNING: unknown ui"
+						"d %d, owner and group ACLs wi"
+						"ll be ineffective\n",
+						fd, c->uid);
 			}
 			sprintf(buf, "client %d is %.200s (uid %d, gids",
 				 			fd, arg, c->uid);
@@ -657,7 +689,7 @@ static void eval_message(
 				p += strlen(p);
 			}
 			strcpy(p, ")\n");
-			log(buf);
+			logger(buf);
 		}
 		endpwent();
 		break;
@@ -673,18 +705,18 @@ static void eval_message(
 		for (p=arg; *p && *p != '\n'; p++);
 		*p = 0;
 		if ((n = open_file(arg, fd, &ronly)) < 0)
-			reply(fd, c, "oft0");
+			reply(fd, "oft0");
 		else
-			reply(fd, c, "ot%c%d", ronly ? 'r' : 'w', n);
+			reply(fd, "ot%c%d", ronly ? 'r' : 'w', n);
 		break;
 
 	  case 'n':
 		fid = atoi(arg);
-		reply(fd, c, "n%d %d", fid, count_rows(fid, fd));
+		reply(fd, "n%d %d", fid, count_rows(fid, fd));
 		break;
 
 	  case 'c':
-		close_file(atoi(arg), fd, c);
+		close_file(atoi(arg), fd);
 		break;
 
 	  case 'r':
@@ -701,7 +733,7 @@ static void eval_message(
 		else
 			rid = add_row(fid, rid, fd, arg,
 				      c->in.enq - (arg-c->in.data));
-		reply(fd, c, "w%c%d", "tf"[!rid], rid);
+		reply(fd, "w%c%d", "tf"[!rid], rid);
 		break;
 
 	  case 'd':
@@ -713,7 +745,7 @@ static void eval_message(
 	  case 'l':
 		fid = atoi(arg); SKIP(arg);
 		rid = atoi(arg);
-		reply(fd, c, "l%c", "ft"[(int)lock_row(fid, rid, fd, TRUE)]);
+		reply(fd, "l%c", "ft"[(int)lock_row(fid, rid, fd, TRUE)]);
 		break;
 
 	  case 'u':
@@ -728,7 +760,7 @@ static void eval_message(
 		struct buffer *out = &client_list[fd].out;
 		char msg[512];
 		for (i=0; i < max_files; i++) {
-			register struct pfile *f = &file_list[i];
+			struct pfile *f = &file_list[i];
 			if (!f->name) continue;
 			sprintf(msg, "\\\n.file %2d: ro=%d mod=%d "
 				"err=%d type=%d nrows=%d "
@@ -755,21 +787,21 @@ static void eval_message(
 		break; }
 
 	  case 'L':
-		if (dir = opendir(HOMEDIR "/" NETDIR)) {
-			while (entry = readdir(dir))
+		if ((dir = opendir(HOMEDIR "/" NETDIR))) {
+			while ((entry = readdir(dir)))
 				if (entry->d_name[0] != '.')
-					reply(fd, c, "Lt%s", entry->d_name);
+					reply(fd, "Lt%s", entry->d_name);
 			closedir(dir);
-			reply(fd, c, "Lt");
+			reply(fd, "Lt");
 		} else
-			reply(fd, c, "Lf");
+			reply(fd, "Lf");
 		break;
 
 	  case 'q':
 		close_client(fd);
 		FD_CLR(fd, &rd0);
 		close(fd);
-		log("client %d disconnected\n", fd);
+		logger("client %d disconnected\n", fd);
 		break;
 
 	  default:
@@ -829,8 +861,7 @@ static void notify_client(
 static BOOL check_file(
 	FILE		*fp,		/* open file to check */
 	char		*fname,		/* file name for error messages */
-	int		fd,		/* client fd */
-	struct client   *c)             /* client that requests check */
+	int		fd)		/* client fd */
 {
 	struct stat	sbuf;		/* check for directories */
 	char		*msg = 0;	/* file error message */
@@ -850,7 +881,7 @@ static BOOL check_file(
 	if (msg) {
 		error(0,  msg, fname, " (this is a security risk)");
 		error(fd, msg, fname, "\\\n(this is a security risk).");
-		log("client %d fails to open %.80s\n", fd, fname);
+		logger("client %d fails to open %.80s\n", fd, fname);
 		return(FALSE);
 	}
 	return(TRUE);
@@ -917,16 +948,16 @@ static int open_file(
 			if (!f->client[fd])
 				f->nclients++;
 			f->client[fd] = ro ? 1 : 2;
-			log("client %d opens cached file %.200s %.20s\n", fd,
-					fname, ro ? "readonly" : "readwrite");
+			logger("client %d opens cached file %.200s %.20s\n",
+				    fd, fname, ro ? "readonly" : "readwrite");
 			*ronly = ro;
 			return(fid);
 		}
 	}
 	path = allocate(strlen(HOMEDIR "/" NETDIR "/") + strlen(fname) + 1);
 	sprintf(path, HOMEDIR "/" NETDIR "/%s", fname);
-	if (fp = fopen(path, "r")) {			/* open and check */
-		if (!check_file(fp, path, fd, c)) {
+	if ((fp = fopen(path, "r"))) {			/* open and check */
+		if (!check_file(fp, path, fd)) {
 			release(path);
 			fclose(fp);
 			return(-1);
@@ -991,11 +1022,11 @@ static int open_file(
 				buf = reallocate(buf, size += BUFINC);
 			buf[i++] = c;
 		}
-		log("client %d opens new file %.20s (type %d), read %d entrie"
-					"s\n", fd, fname, f->type, f->nrows);
+		logger("client %d opens new file %.20s (type %d), read %d entr"
+					"ies\n", fd, fname, f->type, f->nrows);
 		fclose(fp);
 	} else
-		log("client %d opens non-existing file %.20s\n", fd, fname);
+		logger("client %d opens non-existing file %.20s\n", fd, fname);
 	release(buf);
 	f->client[fd] = ro ? 1 : 2;	/* do this here to avoid notify msgs */
 	f->nclients   = 1;
@@ -1013,20 +1044,19 @@ static int open_file(
 
 static void close_file(
 	int		fid,		/* file to close */
-	int		fd,		/* client's fd */
-	struct client  *c)              /* client that closes the file */
+	int		fd)		/* client's fd */
 {
 	int		r;		/* row counter for releasing */
 	struct pfile	*f = &file_list[fid];
 
 	if (fid < 0 || fid >= max_files || !f->name || !f->client[fd])
 		return;
-	log("client %d closes file %.20s\n", fd, f->name);
+	logger("client %d closes file %.20s\n", fd, f->name);
 	write_file(fid);			/* write changes */
 	f->client[fd] = 0;			/* detach client from file */
 	f->nclients--;
 	if (!f->nclients && !f->error) {	/* last client gone: uncache */
-		log("uncaching file %.20s\n", f->name);
+		logger("uncaching file %.20s\n", f->name);
 		for (r=0; r < f->nrows; r++)
 			release(f->row[r].data);
 		release(f->row);
@@ -1084,8 +1114,12 @@ static void do_write(			/* called by previous function only */
 
 	unlink(npath);
 	if (!(fp = fopen(npath, "w+"))) {
-		sprintf(buf, "cannot create temporary data file\\\n%.20s",
-									npath);
+		sprintf(buf, "%.99s: cannot create temporary data file %.99s",
+							progname, npath);
+		if (to_syslog)
+			syslog(LOG_ERR, "%s\n", buf);
+		else
+			fprintf(stderr, "%s\n", buf);
 		return;
 	}
 	if (chmod(npath, 0666))
@@ -1099,8 +1133,12 @@ static void do_write(			/* called by previous function only */
 	if (fclose(fp))
 		err = TRUE;
 	if (err) {
-		sprintf(buf, "cannot write temporary data file\\\n%.20s",
-									npath);
+		sprintf(buf, "%.99s: cannot write temporary data file %.99s",
+							progname, npath);
+		if (to_syslog)
+			syslog(LOG_ERR, "%s\n", buf);
+		else
+			fprintf(stderr, "%s\n", buf);
 		return;
 	}
 	unlink(path);
@@ -1108,7 +1146,12 @@ static void do_write(			/* called by previous function only */
 		err = TRUE;
 	unlink(npath);
 	if (err) {
-		sprintf(buf, "cannot rename data file %.20s", path);
+		sprintf(buf, "%.99s: cannot rename data file %.99s",
+							progname, path);
+		if (to_syslog)
+			syslog(LOG_ERR, "%s\n", buf);
+		else
+			fprintf(stderr, "%s\n", buf);
 		return;
 	}
 	for (r=0, row=f->row; r < f->nrows; r++, row++)
@@ -1118,7 +1161,7 @@ static void do_write(			/* called by previous function only */
 			f->client[fd] = 2;
 	f->modified = FALSE;
 	f->error = FALSE;
-	log("written data file %.400s\n", path);
+	logger("written data file %.400s\n", path);
 }
 
 
@@ -1132,13 +1175,13 @@ static void do_write(			/* called by previous function only */
 #define ROWINC	256			/* increase row table size by chunks */
 
 static int find_row(
-	int			fid,		/* file to close */
-	unsigned int		rid,		/* ID of new row; 0=unknown */
-	BOOL			*found)		/* set if found, clear if ins*/
+	int		fid,		/* file to close */
+	unsigned int	rid,		/* ID of new row; 0=unknown */
+	BOOL		*found)		/* set if found, clear if ins*/
 {
-	int			lo, mid, hi;	/* for binary search for ID */
-	register struct row	*row;		/* current row */
-	struct pfile		*f = &file_list[fid];
+	int		lo, mid, hi;	/* for binary search for ID */
+	struct row	*row;		/* current row */
+	struct pfile	*f = &file_list[fid];
 
 	*found = FALSE;
 	if (!f->nrows)					/* empty list */
@@ -1170,16 +1213,16 @@ static int find_row(
 #define ROWINC	256			/* increase row table size by chunks */
 
 static unsigned int add_row(
-	int			fid,		/* file to close */
-	unsigned int		rid,		/* ID of new row; 0=unknown */
-	int			fd,		/* client that caused add */
-	char			*data,		/* data to store in row */
-	int			len)		/* number of data bytes */
+	int		fid,		/* file to close */
+	unsigned int	rid,		/* ID of new row; 0=unknown */
+	int		fd,		/* client that caused add */
+	char		*data,		/* data to store in row */
+	int		len)		/* number of data bytes */
 {
-	struct pfile		*f = &file_list[fid];
-	int			index, i;	/* index of new row in table */
-	BOOL			found = FALSE;	/* replace existing row? */
-	register struct row	*row;		/* current row */
+	struct pfile	*f = &file_list[fid];
+	int		index, i;	/* index of new row in table */
+	BOOL		found = FALSE;	/* replace existing row? */
+	struct row	*row;		/* current row */
 
 	if (fid < 0 || fid >= max_files || !f->name)
 		return(0);
@@ -1302,16 +1345,16 @@ static void send_row(
 	BOOL		found;		/* does row exist? err check */
 	int		n, beg, end;	/* index into row table */
 	char		buf[4097];	/* message header and body */
-	register char	*p, *q;		/* for escaping \n with \ */
+	char		*p, *q;		/* for escaping \n with \ */
 
 	if (fid < 0 || fid >= max_files || !f->name || !f->client[fd]) {
-		reply(fd, c, "%cf%d 0 ", opcode, fid);
+		reply(fd, "%cf%d 0 ", opcode, fid);
 		return;
 	}
 	if (rid) {					/* single row */
 		beg = end = find_row(fid, rid, &found);
 		if (!found) {
-			reply(fd, c, "%cf%d %d ", opcode, fid, rid);
+			reply(fd, "%cf%d %d ", opcode, fid, rid);
 			return;
 		}
 	} else {					/* all rows */
@@ -1323,7 +1366,7 @@ static void send_row(
 		sprintf(buf, "%ct%d %d ", opcode, fid, row->id);
 		appendbuf(&c->out, buf, strlen(buf));
 		if (verbose)
-			log("client %d reply %.50s<data>\n", fd, buf);
+			logger("client %d reply %.50s<data>\n", fd, buf);
 		for (p=row->data; *p; ) {
 			for (q=buf; *p && q < buf+sizeof(buf)-1; ) {
 				if (*p == '\n') {
@@ -1365,12 +1408,16 @@ static int count_rows(
 static void fatal(char *fmt, ...)
 {
 	va_list		parm;
+	char		msg[1024];
 
 	va_start(parm, fmt);
-	fprintf(stderr, "%s: ", progname);
-	vfprintf(stderr, fmt, parm);
+	sprintf(msg, "%.99s: fatal error: ", progname);
+	vsnprintf(msg+strlen(msg), 850, fmt, parm);
+	if (to_syslog)
+		syslog(LOG_ERR, "%s, exiting.\n", msg);
+	else
+		fprintf(stderr, "%s, exiting.\n", msg);
 	va_end(parm);
-	fprintf(stderr, ", exiting.\n");
 	exit(1);
 }
 
@@ -1382,7 +1429,7 @@ static void fatal(char *fmt, ...)
  * is too small!
  */
 
-static void reply(int fd, struct client *c, char *fmt, ...)
+static void reply(int fd, char *fmt, ...)
 {
 	va_list		parm;
 	char		msg[4096];
@@ -1392,7 +1439,7 @@ static void reply(int fd, struct client *c, char *fmt, ...)
 	strcat(msg, "\n");
 	appendbuf(&client_list[fd].out, msg, strlen(msg));
 	if (verbose)
-		log("client %d reply %.400s", fd, msg);
+		logger("client %d reply %.400s\n", fd, msg);
 	FD_SET(fd, &wr0);
 }
 
@@ -1419,9 +1466,12 @@ void error(int fd, char *fmt, ...)
 		if (fd)
 			FD_SET(fd, &wr0);
 	} else {
-		fprintf(stderr, "%s: error: ", progname);
-		vfprintf(stderr, fmt, parm);
-		putc('\n', stderr);
+		sprintf(msg, "%.99s: error: ", progname);
+		vsnprintf(msg+strlen(msg), 3800, fmt, parm);
+		if (to_syslog)
+			syslog(LOG_ERR, "%s\n", msg);
+		else
+			fprintf(stderr, "%s\n", msg);
 	}
 	va_end(parm);
 }
@@ -1431,14 +1481,19 @@ void error(int fd, char *fmt, ...)
  * print verbose logging message
  */
 
-void log(char *fmt, ...)
+void logger(char *fmt, ...)
 {
 	va_list		parm;
+	char		msg[1024];
 
 	if (debug) {
 		va_start(parm, fmt);
-		fprintf(stderr, "%s: ", progname);
-		vfprintf(stderr, fmt, parm);
+		sprintf(msg, "%.99s: ", progname);
+		vsnprintf(msg+strlen(msg), 900, fmt, parm);
+		if (to_syslog)
+			syslog(LOG_DEBUG, "%s", msg);
+		else
+			fprintf(stderr, "%s", msg);
 		va_end(parm);
 	}
 }
@@ -1448,7 +1503,8 @@ void log(char *fmt, ...)
  * return static string describing an IP address with port number
  */
 
-char *ip_addr(register struct sockaddr_in *addr)
+char *ip_addr(
+	struct sockaddr_in *addr)
 {
 	static char buf[64];
 	unsigned long a = ntohl(addr->sin_addr.s_addr);
