@@ -20,7 +20,7 @@
 #include <string.h>
 #include <stdarg.h>
 #include <sys/types.h>
-#ifdef __EMX__
+#if defined(__EMX__) || defined(LINUX)
 #include <sys/wait.h>
 #endif
 #include <Xm/Xm.h>
@@ -42,7 +42,7 @@ extern Display		*display;	/* everybody uses the same server */
 extern Widget		mainwindow;	/* popup menus hang off main window */
 extern XtAppContext	app;		/* application handle */
 extern BOOL		interactive;	/* interactive or fast appt entry? */
-extern BOOL		startup_lock();
+extern BOOL		startup_lock(BOOL, BOOL);
 
 
 /*---------------------------------------------------------- about ----------*/
@@ -51,23 +51,21 @@ static char about_message[] = "\
 Day Planner version %s\n\
 Compiled %s\n\n\
 Author: Thomas Driemeyer\n\
-<thomas@bitrot.de, thomas@bitrot.in-berlin.de>\n\n\
-Send mail to majordomo@bitrot.de to subscribe\n\
-to the mailing list.  Or check out my home page:\n\n\
-http://www.bitrot.de\n\
-http://www.in-berlin.de/User/bitrot\n\n\
+<thomas@bitrot.de>\n\
+http://www.bitrot.de\n\n\
 The sources are available at\n\
+ftp://ftp.bitrot.de and\n\
 ftp://plan.ftp.fu-berlin.de\
 \n";
 
 
 void create_about_popup(void)
 {
-	char			msg[512];
-	Widget			dialog;
-	XmString		s;
-	Arg			args[10];
-	int			n;
+	char		msg[512];
+	Widget		dialog;
+	XmString	s;
+	Arg		args[10];
+	int		n;
 
 	sprintf(msg, _(about_message), VERSION JAPANVERSION, __DATE__);
 	s = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
@@ -84,15 +82,15 @@ void create_about_popup(void)
 
 /*---------------------------------------------------------- errors ---------*/
 void create_error_popup(
-	Widget			widget,
-	int			error,
-	char			*fmt, ...)
+	Widget		widget,
+	UNUSED int	error,
+	char		*fmt, ...)
 {
-	va_list			parm;
-	char			msg[10240];
-	Widget			dialog;
-	XmString		string;
-	Arg			args;
+	va_list		parm;
+	char		msg[10240];
+	Widget		dialog;
+	XmString	string;
+	Arg		args;
 
 	if (!widget)
 		widget = mainwindow;
@@ -136,11 +134,11 @@ static BOOL running;
 
 void create_nodaemon_popup(void)
 {
-	char			msg[512];
-	Widget			dialog;
-	XmString		s1, s2, s3;
-	Arg			args[10];
-	int			n;
+	char		msg[512];
+	Widget		dialog;
+	XmString	s1, s2, s3;
+	Arg		args[10];
+	int		n;
 
 	if (running)
 		return;
@@ -179,7 +177,7 @@ void create_nodaemon_popup(void)
 
 /*ARGSUSED*/
 void run_daemon(
-	Widget		dialog)		/* not used */
+	UNUSED Widget	dialog)		/* not used */
 {
 	char		path[1024];
 	PID_T		pid;
@@ -224,7 +222,7 @@ void run_daemon(
 
 /*ARGSUSED*/
 static void cancel_callback(
-	Widget		dialog)
+	UNUSED Widget	dialog)
 {
 	running = FALSE;
 	suppress_daemon_warning = True;
@@ -292,11 +290,11 @@ void create_multiple_popup(
 
 /*ARGSUSED*/
 static void kill_callback(
-	Widget		dialog,
-	XtPointer	a,
-	XtPointer	b)
+	UNUSED Widget	 dialog,
+	UNUSED XtPointer a,
+	UNUSED XtPointer b)
 {
-	if (!startup_lock(resolve_tilde(PLANLOCK), TRUE))
+	if (!startup_lock(FALSE, TRUE))
 		create_multiple_popup(TRUE);
 	cont = TRUE;
 }
@@ -309,9 +307,9 @@ static void kill_callback(
 
 /*ARGSUSED*/
 static void cont_callback(
-	Widget		dialog,
-	XtPointer	a,
-	XtPointer	b)
+	UNUSED Widget	 dialog,
+	UNUSED XtPointer a,
+	UNUSED XtPointer b)
 {
 	cont = TRUE;
 }
