@@ -353,7 +353,7 @@ void destroy_print_popup(void)
 
 /*ARGSUSED*/
 static void mode_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -366,8 +366,8 @@ static void mode_callback(
 
 /*ARGSUSED*/
 static void omit_appts_callback(
-	Widget				widget,
-	int				item,
+	UNUSED Widget			widget,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	config.pr_omit_appts = data->set;
@@ -377,8 +377,8 @@ static void omit_appts_callback(
 
 /*ARGSUSED*/
 static void omit_priv_callback(
-	Widget				widget,
-	int				item,
+	UNUSED Widget			widget,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	config.pr_omit_priv  = data->set;
@@ -388,8 +388,8 @@ static void omit_priv_callback(
 
 /*ARGSUSED*/
 static void omit_others_callback(
-	Widget 				 widget,
-	int    				 item,
+	UNUSED Widget 			 widget,
+	UNUSED int    			 item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	config.pr_omit_others  = data->set;
@@ -399,8 +399,8 @@ static void omit_others_callback(
 
 /*ARGSUSED*/
 static void color_callback(
-	Widget 				 widget,
-	int    				 item,
+	UNUSED Widget 			 widget,
+	UNUSED int    			 item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	config.pr_color    = data->set;
@@ -410,9 +410,9 @@ static void color_callback(
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct *data)
 {
 	destroy_print_popup();
 }
@@ -430,10 +430,10 @@ static void broken_pipe_handler(
 
 /*ARGSUSED*/
 static void print_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
-{
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct *data)
+	{
 	FILE	*pp;
 	char	*Spooler = XmTextFieldGetString(spool_text);
 	char	tmp[128];
@@ -644,7 +644,7 @@ static int Print_Day(
 	fprintf(fp, "%d %d %d %d %d NewDay\n",
 				Month+1, Day, Year, WeekNum+1, JulDay+1);
 
-	if (hp->string && *hp->string || hp2->string && *hp2->string) {
+	if ((hp->string && *hp->string) || (hp2->string && *hp2->string)) {
 		fprintf(fp, "[ ");
 		for (j=0; j < 2; j++, hp=hp2) {
 			if (!hp->string || !*hp->string)
@@ -671,11 +671,11 @@ static int Print_Day(
 	for (; found; found = lookup_next_entry(&lookup)) {
 		entry = &mainlist->entry[lookup.index];
 
-		if (config.pr_mode == PR_MONTH && entry->hide_in_m ||
-		    config.pr_mode == PR_YEAR  && entry->hide_in_y)
+		if ((config.pr_mode == PR_MONTH && entry->hide_in_m) ||
+		    (config.pr_mode == PR_YEAR  && entry->hide_in_y))
 			continue;
-		if (Mode == PR_MONTH && entry->hide_in_m ||
-		    Mode == PR_YEAR  && entry->hide_in_y)
+		if ((Mode == PR_MONTH && entry->hide_in_m) ||
+		    (Mode == PR_YEAR  && entry->hide_in_y))
 			continue;
 		u = name_to_user(entry->user);
 		if (user[u].suspend_m)
