@@ -20,7 +20,7 @@ extern void do_get_rsrc(		/* read resource */
 	char		*res_class_name,
 	char		*res_type);
 extern char *mystrdup(			/* strdup replacement for Ultrix */
-	register char *s);
+	char		*s);
 extern void exit(			/* local version of exit w/ writeback*/
 	int		ret);
 extern void fatal(			/* print error message and exits */
@@ -144,7 +144,6 @@ extern void parse_file_line(		/* parse one line from appt file */
 	struct plist	**list,		/* list to add to */
 	char		*path,		/* file/server to read from */
 	char		*name,		/* user name, 0=not yet known*/
-	BOOL		conf,		/* if TRUE, config stuff too */
 	char		*line);		/* line to be parsed */
 
 /*---------------------------------------- file_w.c ------------*/
@@ -157,6 +156,11 @@ extern int  write_one_entry(		/* write one entry to file or server */
 	int		(*callback)(),	/* function that writes line */
 	struct entry	*ep);		/* list entry to write */
 
+/*---------------------------------------- vcalendar_w.c ------------*/
+
+extern void write_vcal_mainlist(
+	char		*path);		/* write vCalendar data to this file */
+
 /*---------------------------------------- help.c ------------*/
 
 extern void help_callback(		/* print help for a topic */
@@ -208,6 +212,8 @@ extern int day_from_wday(
 	int		day,
 	int		wday,
 	int		num);
+extern void dump_holiday(
+	int		year);
 
 /*---------------------------------------- util.c ------------*/
 
@@ -218,7 +224,7 @@ extern BOOL find_file(			/* find file <name> and store path */
 	char		*name,		/* file name to locate */
 	BOOL		exec);		/* must be executable? */
 extern BOOL startup_lock(		/* make sure program runs only once */
-	char		*pathtmp,	/* PLANDLOCK or PLANLOCK */
+	BOOL		pland,		/* is this plan or pland? */
 	BOOL		force);		/* kill competitor */
 extern BOOL refresh_lock(
 	char		*pathtmp);	/* PLANDLOCK or PLANLOCK */
@@ -230,7 +236,7 @@ extern int mystrcasecmp(		/* local version of strcasecmp */
 	char		*b);
 void mybzero(
 	void		*p,
-	register int	n);
+	int		n);
 void print_info_line(void);
 char to_ascii(
 	char		*str,		/* string to convert to ascii */
