@@ -177,13 +177,24 @@ void create_serv_popup(void)
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	16);			n++;
-	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
-	XtSetArg(args[n], XmNleftOffset,	16);			n++;
+	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_WIDGET);	n++;
+	XtSetArg(args[n], XmNrightWidget,	w);			n++;
+	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
 	w = XtCreateManagedWidget(_("Add"), xmPushButtonWidgetClass,
 			form, args, n);
 	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
 			add_callback, (XtPointer)0);
+	n = 0;
+	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNbottomOffset,	16);			n++;
+	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
+	XtSetArg(args[n], XmNleftOffset,	16);			n++;
+	XtSetArg(args[n], XmNwidth,		80);			n++;
+	w = XtCreateManagedWidget(_("Query"), xmPushButtonWidgetClass,
+			form, args, n);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			text_callback, (XtPointer)0);
 
 						/*--------- list ------------*/
 	n = 0;
@@ -225,9 +236,9 @@ void create_serv_popup(void)
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_serv_popup();
 }
@@ -236,8 +247,8 @@ static void done_callback(
 /*ARGSUSED*/
 static void text_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	int				i;
 	Arg				args[2];
@@ -268,9 +279,9 @@ static void text_callback(
 
 /*ARGSUSED*/
 static void add_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	int				n, i, u, eq, *pos;
 	char				buf[1024];
