@@ -126,13 +126,13 @@ BOOL can_edit_appts(void)
  */
 
 static void copyuser(
-	register struct user	**tar,		/* lists to copy */
-	int			*ntar,		/* list sizes to copy */
-	register struct user	*src,
-	int			nsrc)
+	struct user	**tar,		/* lists to copy */
+	int		*ntar,		/* list sizes to copy */
+	struct user	*src,
+	int		nsrc)
 {
-	register struct user	*u;		/* target scan pointer */
-	register int		i;		/* target counter */
+	struct user	*u;		/* target scan pointer */
+	int		i;		/* target counter */
 
 	if (*tar) {
 		for (u=*tar, i=*ntar; i; i--, u++) {
@@ -174,16 +174,16 @@ static void copyuser(
 
 static BOOL accept_new_list(void)
 {
-	register struct entry	*ep;
-	register struct user	*up;
-	register int		u, i, nlocal, nremote;
-	char			*msg;
+	struct entry	*ep;
+	struct user	*up;
+	int		u, i, nlocal, nremote;
+	char		*msg;
 
 	for (u=nusers-1; u >= 0; u--)
 		if (!user[u].prev_fromserver && user[u].fromserver)
 			break;
 	if (u >= 0) {
-	    if (msg = attach_to_network()) {
+	    if ((msg = attach_to_network())) {
 		create_error_popup(shell, 0, msg);
 		free(msg);
 		return(FALSE);
@@ -195,15 +195,15 @@ static BOOL accept_new_list(void)
 		nlocal  = 0;
 		ep = mainlist->entry;
 		for (i=mainlist->nentries-1; i >= 0; i--, ep++)
-			nlocal += !ep->user && !u ||
-				   ep->user && !strcmp(ep->user, up->name);
+			nlocal += (!ep->user && !u) ||
+				  (ep->user && !strcmp(ep->user, up->name));
 		if (!nlocal)
 			continue;
 		if (!nremote) {
 			ep = mainlist->entry;
 			for (i=mainlist->nentries-1; i >= 0; i--, ep++)
-				if (!ep->user && !u ||
-				    !strcmp(ep->user, up->name)) {
+				if ((!ep->user && !u) ||
+				     !strcmp(ep->user, up->name)) {
 					ep->id   = 0;
 					ep->file = up->file_id;
 					if (!server_entry_op(ep, 'w'))
@@ -466,11 +466,11 @@ void create_user_rows(void)
 	int			x, y, xo;
 	Arg			args[20];
 	int			n;
-	int			align;
-	BOOL			shadow;
-	String			callbk;
+	int			align = XmALIGNMENT_CENTER;
+	BOOL			shadow = FALSE;
+	String			callbk = 0;
 	char			*name;
-	WidgetClass		class;
+	WidgetClass		class = 0;
 
 	if (!cell_x[0])
 		for (x=4, n=0; n < NCOLUMNS; x+=cell_xs[n++]) {
@@ -484,8 +484,8 @@ void create_user_rows(void)
 		return;
 
 	n = (nrows+1) * (NCOLUMNS+2) * sizeof(Widget *);
-	if (utable && !(utable = (Widget (*)[])realloc(utable, n)) ||
-	   !utable && !(utable = (Widget (*)[])malloc(n)))
+	if ((utable && !(utable = (Widget (*)[])realloc(utable, n))) ||
+	   (!utable && !(utable = (Widget (*)[])malloc(n))))
 		fatal(_("no memory"));
 							/* build list */
 	XtUnmanageChild(ulist);
@@ -621,14 +621,14 @@ static char *default_server(
  */
 
 static void edit_user_button(
-	BOOL			doedit,		/* TRUE=edit, FALSE=unedit */
-	int			x,		/* column, 0..NCOLUMNS-1* */
-	int			y)		/* row, y=0: title */
+	BOOL		doedit,		/* TRUE=edit, FALSE=unedit */
+	int		x,		/* column, 0..NCOLUMNS-1* */
+	int		y)		/* row, y=0: title */
 {
-	register struct user	*u;
-	Arg			args[15];
-	int			n;
-	char			*text, buf[1024];
+	struct user	*u;
+	Arg		args[15];
+	int		n;
+	char		*text, buf[1024];
 
 	if (textwidget) {
 		BOOL free_string = TRUE;
@@ -701,13 +701,13 @@ static void edit_user_button(
  */
 
 static void got_user_text(
-	int			x,		/* column, 0..NCOLUMNS-1* */
-	int			y,		/* row, y=0: title */
-	char			*string)	/* text entered by user */
+	int		x,		/* column, 0..NCOLUMNS-1* */
+	int		y,		/* row, y=0: title */
+	char		*string)	/* text entered by user */
 {
-	register struct user	*u;
-	char			buf[100], *p;
-	int			i;
+	struct user	*u;
+	char		buf[100], *p;
+	int		i;
 
 	if (!y--)
 		return;
@@ -731,8 +731,8 @@ static void got_user_text(
 	}
 	if (y >= nusers) {
 		int n = ++nusers * sizeof(struct user);
-		if (user && !(user = (struct user *)realloc(user, n)) ||
-		   !user && !(user = (struct user *)malloc(n)))
+		if ((user && !(user = (struct user *)realloc(user, n))) ||
+		   (!user && !(user = (struct user *)malloc(n))))
 			fatal(_("no memory"));
 		y = nusers-1;
 		u = user + y;
@@ -791,11 +791,11 @@ static void got_user_text(
  */
 
 void draw_user_row(
-	int			y)
+	int		y)
 {
-	Widget			*urow = utable[y];
-	Arg			args[3];
-	register struct user	*u = &user[y-1];
+	Widget		*urow = utable[y];
+	Arg		args[3];
+	struct user	*u = &user[y-1];
 
 	if (y < 1)
 		return;
@@ -857,9 +857,9 @@ void draw_user_row(
 
 /*ARGSUSED*/
 static void delete_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	int				n;
 	Arg				args;
@@ -892,16 +892,16 @@ static void delete_callback(
 #define CONST const
 #endif
 
-static int compare(u, v) register CONST void *u, *v; {
+static int compare(CONST void *u, CONST void *v) {
 	return(  ((struct user *)u)->color == ((struct user *)v)->color
 	? strcmp(((struct user *)u)->name,    ((struct user *)v)->name)
 	:        ((struct user *)u)->color -  ((struct user *)v)->color); }
 
 /*ARGSUSED*/
 static void sort_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	Arg				args;
 	int				n;
@@ -919,9 +919,9 @@ static void sort_callback(
 
 /*ARGSUSED*/
 static void browse_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit_user_button(FALSE, 0, 0);
 	create_serv_popup();
@@ -930,9 +930,9 @@ static void browse_callback(
 
 /*ARGSUSED*/
 static void cancel_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_user_popup(FALSE);
 }
@@ -940,9 +940,9 @@ static void cancel_callback(
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_user_popup(TRUE);
 }
@@ -957,10 +957,10 @@ static void done_callback(
 
 #ifdef XmCSimpleOptionMenu
 static Widget call_popup_callback(
-	Widget		widget,
+	UNUSED Widget	widget,
 	XtPointer	y,
         XEvent		*event,
-	Boolean		*cont)
+	UNUSED Boolean	*cont)
 {
 	Widget popup = utable[(long)y][COLPOPUP];
 	event->xbutton.x += 19;
@@ -984,7 +984,7 @@ static Widget call_popup_callback(
 
 /*ARGSUSED*/
 static void list_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -1066,9 +1066,9 @@ static void list_callback(
 
 /*ARGSUSED*/
 static void got_text(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	edit_user_button(FALSE, 0, 0);
 }
