@@ -59,7 +59,7 @@ void destroy_user_sel_popup(void)
  */
 
 void create_user_sel_popup(
-	Widget		widget,		/* install popup near this button */
+	UNUSED Widget	widget,		/* install popup near this button */
 	int		curr,		/* current user ID (default) */
 	BOOL		(*callb)())	/* function to call with new user ID */
 {
@@ -154,7 +154,7 @@ void create_user_sel_popup(
 
 /*ARGSUSED*/
 static void user_sel_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
 	XmToggleButtonCallbackStruct	*data)
 {
@@ -167,9 +167,9 @@ static void user_sel_callback(
 
 /*ARGSUSED*/
 static void abort_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	destroy_user_sel_popup();
 }
