@@ -84,7 +84,7 @@ char *resolve_tilde(
 		for (p=path+1, q=pathbuf; *p && *p != '/'; p++, q++)
 			*q = *p;
 		*q = 0;
-		if (pw = getpwnam(pathbuf)) {
+		if ((pw = getpwnam(pathbuf))) {
 			home = pw->pw_dir;
 			path = p-1;
 		}
@@ -111,14 +111,14 @@ char *resolve_tilde(
 #endif
 
 BOOL find_file(
-	char			*buf,		/* buffer for returned path */
-	char			*name,		/* file name to locate */
-	BOOL			exec)		/* must be executable? */
+	char		*buf,		/* buffer for returned path */
+	char		*name,		/* file name to locate */
+	BOOL		exec)		/* must be executable? */
 {
-	int			method;		/* search path counter */
-	char			*path;		/* $PATH or DEFAULTPATH */
-	int			namelen;	/* len of tail of name */
-	register char		*p, *q;		/* string copy pointers */
+	int		method;		/* search path counter */
+	char		*path;		/* $PATH or DEFAULTPATH */
+	int		namelen;	/* len of tail of name */
+	char		*p, *q;		/* string copy pointers */
 
 	if (*name == '/') {				/* begins with / */
 		strcpy(buf, name);
@@ -168,15 +168,19 @@ BOOL find_file(
  * TRUE, try to kill it. Otherwise, return FALSE.
  */
 
+static BOOL check_process(BOOL, PID_T);
+
 BOOL startup_lock(
-	char			*pathtmp,	/* PLANDLOCK or PLANLOCK */
+	BOOL			pland,		/* is this plan or pland? */
 	BOOL			force)		/* kill competitor */
 {
+	char			*pathtmp;	/* name of lockfile */
 	char			buf[2048];	/* lockfile contents */
 	int			lockfd;		/* lock/pid file */
 	PID_T			pid;		/* pid in lockfile */
 	int			retry = 5;	/* try to kill daemon 5 times*/
 
+	pathtmp = resolve_tilde(pland ? PLANDLOCK : PLANLOCK);
 	sprintf(buf, pathtmp, (int)getuid());
 	strncpy(lockpath, resolve_tilde(buf), sizeof(lockpath)-1);
 	lockpath[sizeof(lockpath)-1] = 0;
@@ -200,6 +204,8 @@ BOOL startup_lock(
 		buf[10] = 0;
 		pid = atoi(buf);
 		close(lockfd);
+		if (pid == getpid())
+			break;
 		if (!retry--)
 			fprintf(stderr,
 			_("%s: failed to kill process %d owning lockfile %s\n"),
@@ -208,25 +214,35 @@ BOOL startup_lock(
 		if (kill(pid, 0) && errno == ESRCH) {
 			if (unlink(lockpath) && errno != ENOENT) {
 				int err = errno;
-				fprintf(stderr,
-					_("%s: cannot unlink lockfile "),
-								progname);
+				fprintf(stderr, _("%s: cannot unlink lockfile "
+						), progname);
 				errno = err;
 				perror(lockpath);
-				_exit(1);
+				return(FALSE);
 			}
 			continue;
 		}
 #		endif
 		if (!force)
 			return(FALSE);
-		if (pid != getpid())
-			(void)kill(pid, retry == 4 ? SIGINT : SIGTERM);
+
+		/* if check_process is functional (works on current process),
+		 * check whether the pid in the lockfile is really plan/pland.
+		 * if yes (or if check_process is broken), kill the old pid. */
+		if (check_process(pland, getpid()) &&
+		   !check_process(pland, pid)) {
+			fprintf(stderr, _("%s: process %d owning lockfile %s "
+				"no longer exists, not killing"),
+				progname, pid, pathtmp);
+			unlink(pathtmp);
+			break;
+		}
+		(void)kill(pid, retry == 4 ? SIGINT : SIGTERM);
 		sleep(1);
 	}
 	sprintf(buf, _("%5d      (pid of lockfile for %s, for user %d)\n"),
 				(int)getpid(), progname, (int)getuid());
-	if (write(lockfd, buf, strlen(buf)) != strlen(buf)) {
+	if (write(lockfd, buf, (int)strlen(buf)) != (int)strlen(buf)) {
 		int err = errno;
 		fprintf(stderr, _("%s: cannot write lockfile "), progname);
 		errno = err;
@@ -237,9 +253,52 @@ BOOL startup_lock(
 	return(TRUE);
 }
 
+
+/*
+ * given a pid (read from the lockfile), make sure it really belongs to a
+ * process called "plan" or "pland". The expected process might have died
+ * and the pid might have been reused by some other process, which we do
+ * not want to kill. Return TRUE if the process is still plan or pland.
+ */
+
+static BOOL check_process(
+	BOOL			pland,		/* false: plan, true: pland */
+	PID_T			pid)		/* check this process ID */
+{
+#ifdef LINUX
+	struct stat		statbuf;	/* for checking ownership */
+	char			buf[1024];	/* lockfile contents */
+	int			fd;		/* /proc/%d/... file */
+	char			*p;		/* for mangling the prog name*/
+	int			i;
+
+	sprintf(buf, "/proc/%u/cmdline", pid);
+	if (stat(buf, &statbuf) < 0)			/* read file owner */
+		return(FALSE);
+	if (statbuf.st_uid != getuid())			/* is it us? */
+		return(FALSE);
+	while ((fd = open(buf, O_RDONLY)) < 0)		/* open /proc file */
+		return(FALSE);
+	i = read(fd, buf, sizeof(buf)-1);		/* get cmdline */
+	close(fd);
+	if (i < 1)					/* none found? */
+		return(FALSE);
+	buf[i] = 0;
+	if ((p = strchr(buf, ' ')))			/* isolate first word*/
+		*p = 0;
+	p = strrchr(buf, '/');				/* cut off /path/ */
+	p = p ? p+1 : buf;
+	return(!strcmp(p, pland ? "pland" : "plan"));	/* compare prog name */
+#else
+	return(FALSE);
+#endif
+}
+
+
 /*
  * Create new lock file when it has been deleted (after cleanup of /tmp)
  */
+
 BOOL refresh_lock(
 	char		*pathtmp)	/* PLANDLOCK or PLANLOCK */
 {
@@ -261,7 +320,7 @@ BOOL refresh_lock(
 	}
 	sprintf(buf, _("%5d      (pid of lockfile for %s, for user %d)\n"),
 				(int)getpid(), progname, (int)getuid());
-	if (write(lockfd, buf, strlen(buf)) != strlen(buf)) {
+	if (write(lockfd, buf, (int)strlen(buf)) != (int)strlen(buf)) {
 		int err = errno;
 		fprintf(stderr, _("%s: cannot write lockfile "), progname);
 		errno = err;
@@ -295,9 +354,10 @@ static void alarmhand(
 #endif
 
 
+/* the two UNUSED's below are wrong but they shut up stupid gcc warnings */
 void lockfile(
-	FILE		*fp,		/* file to lock */
-	BOOL		lock)		/* TRUE=lock, FALSE=unlock */
+	UNUSED FILE	*fp,		/* file to lock */
+	UNUSED BOOL	lock)		/* TRUE=lock, FALSE=unlock */
 {
 #ifndef NOLOCK
 	if (lock) {
@@ -354,9 +414,9 @@ void fatal(
  */
 
 char *mystrdup(
-	register char *s)
+	char		*s)
 {
-	register char *p = NULL;
+	char		*p = NULL;
 
 	if (s && (p = (char *)malloc(strlen(s)+1)))
 		strcpy(p, s);
@@ -370,10 +430,10 @@ char *mystrdup(
  */
 
 int mystrcasecmp(
-	register char *a,
-	register char *b)
+	char		*a,
+	char		*b)
 {
-	register char ac, bc;
+	char		ac, bc;
 
 	for (;;) {
 		ac = *a++;
@@ -439,9 +499,9 @@ char to_ascii(
 
 void mybzero(
 	void		*p,
-	register int	n)
+	int		n)
 {
-	register char	*q = p;
+	char		*q = p;
 	while (n--) *q++ = 0;
 }
 
