@@ -69,7 +69,7 @@ void build_week(
 			if (omit_all || lookup.trigger >= date + 86400)
 				break;
 			ep = &mainlist->entry[lookup.index];
-			if (ep->hide_in_w || ep->private && omit_priv)
+			if (ep->hide_in_w || (ep->private && omit_priv))
 				continue;
 			u = name_to_user(ep->user);
 			if (user[u].suspend_w)
@@ -196,7 +196,7 @@ static BOOL add_week_entry(
 				space_avail : config.week_maxnote, FONT_WNOTE);
 	node->textlen = strlen_in_pixels(node->text, FONT_WNOTE);
 #endif
-	node->textinside = new->notime && config.week_bignotime ||
+	node->textinside = (new->notime && config.week_bignotime) ||
 	                   space_avail >= node->textlen;
 
 	if (!week.tree[wday]) {
