@@ -27,6 +27,7 @@ static void gen_week			(void);
 static void draw_week_day_background	(int);
 static void draw_week_day_foreground	(int);
 static void draw_bar			(struct weeknode *, int, int, int);
+static int  drawn_lines;
 
 extern Display		*display;	/* everybody uses the same server */
 extern XFontStruct	*font[NFONTS];	/* fonts: FONT_* */
@@ -57,27 +58,27 @@ extern struct holiday	sm_holiday[366];/* full-line texts under, and small */
  */
 
 MOUSE locate_in_week_calendar(
-	struct entry		**epp,		/* returned entry or 0 */
-	BOOL			*warn,		/* is *epp an n-days-ahead w?*/
-	time_t			*time,		/* if *epp=0, clicked where */
-	time_t			*trigger,	/* if *epp=0, entry trigger */
-	int			*xp,		/* if M_INSIDE, rubber box */
-	int			*yp,
-	int			*xsp,		/* position and size */
-	int			*ysp,
-	int			xc,		/* pixel pos clicked */
-	int			yc)
+	struct entry	**epp,		/* returned entry or 0 */
+	BOOL		*warn,		/* is *epp an n-days-ahead w?*/
+	time_t		*time,		/* if *epp=0, clicked where */
+	time_t		*trigger,	/* if *epp=0, entry trigger */
+	int		*xp,		/* if M_INSIDE, rubber box */
+	int		*yp,
+	int		*xsp,		/* position and size */
+	int		*ysp,
+	int		xc,		/* pixel pos clicked */
+	int		yc)
 {
-	register struct config	*c = &config;
-	struct weeknode		*vert, *horz;	/* yov node scan pointers */
-	register struct entry	*ep;		/* entry to test */
-	int			d;		/* day strip counter */
-	int			yd;		/* y start coord of day box */
-	int			x, y;		/* upper left of day bk box */
-	int			xend;		/* right margin of chart */
-	int			ys;		/* height of bar line w/ gaps*/
-	time_t			bt;		/* start time of bar */
-	int			b, e;		/* X start end end pos of bar*/
+	struct config	*c = &config;
+	struct weeknode	*vert, *horz;	/* yov node scan pointers */
+	struct entry	*ep;		/* entry to test */
+	int		d;		/* day strip counter */
+	int		yd;		/* y start coord of day box */
+	int		x, y;		/* upper left of day bk box */
+	int		xend;		/* right margin of chart */
+	int		ys;		/* height of bar line w/ gaps*/
+	time_t		bt;		/* start time of bar */
+	int		b, e;		/* X start end end pos of bar*/
 
 	x  = c->week_margin + c->week_daywidth + c->week_gap;
 	yd = 2*c->week_margin + c->week_title + c->week_hour + c->week_gap + 2;
@@ -222,10 +223,11 @@ void print_week_calendar(
 
 static void gen_week(void)
 {
-	register struct config	*c = &config;
-	char			buf[40], *p;
-	int			i, l, x, y;
+	struct config	*c = &config;
+	char		buf[40], *p;
+	int		i, l, x, y;
 
+	drawn_lines = 0;
 	for (i=0; i < c->week_ndays; i++)		/* day background */
 		draw_week_day_background(i);
 							/* thick lines */
@@ -280,24 +282,24 @@ void g_draw_strpack();
 #endif
 
 static void draw_week_day_background(
-	int			wday)		/* day of the week, < NDAYS */
+	int		wday)		/* day of the week, < NDAYS */
 {
-	register struct config	*c = &config;
-	time_t			today;		/* today's date */
-	struct holiday		*hp, *shp;	/* to check for holidays */
-	char			*errmsg;	/* holiday parser error */
-	char			buf[20];	/* holiday text buffer */
-	struct tm		*tm;		/* today's date as m/d/y */
-	char			*p;		/* temp for day name */
-	int			x, y;		/* upper left of day bk box */
-	int			ys;		/* height of bar line w/ gaps*/
-	int			yt;		/* text y position */
-	int			yts;		/* vert space for text */
-	int			i;
+	struct config	*c = &config;
+	time_t		today;		/* today's date */
+	struct holiday	*hp, *shp;	/* to check for holidays */
+	char		*errmsg;	/* holiday parser error */
+	char		buf[20];	/* holiday text buffer */
+	struct tm	*tm;		/* today's date as m/d/y */
+	char		*p;		/* temp for day name */
+	int		x, y;		/* upper left of day bk box */
+	int		ys;		/* height of bar line w/ gaps*/
+	int		yt;		/* text y position */
+	int		yts;		/* vert space for text */
+	int		i;
 #ifdef JAPAN
-	int			plen;		/* pixel-length of partialstr */
-	strpack			partialstr[MAXPARTIALSTRING];
-	unsigned char		strpool[MAXPARTIALCHAR];
+	int		plen;		/* pixel-length of partialstr */
+	strpack		partialstr[MAXPARTIALSTRING];
+	unsigned char	strpool[MAXPARTIALCHAR];
 #endif
 
 	if (week.nlines[wday] == 0)
@@ -312,7 +314,7 @@ static void draw_week_day_background(
 	yts = week.nlines[wday] * ys + c->week_gap -1;
 	today = get_time() - (curr_week + wday*86400);
 	g_setcolor(today < 0 || today >= 86400 ? COL_WBACK : COL_CALTODAY);
-	g_fillrect(c->week_margin, y, c->week_daywidth, yts);
+	g_fillrect(c->week_margin, y, c->week_daywidth, yts - c->week_gap);
 
 							/* weekday name */
 	yt = y + font[FONT_WDAY]->max_bounds.ascent;
@@ -326,7 +328,7 @@ static void draw_week_day_background(
 	      font[FONT_WDAY]->max_bounds.descent;
 							/* holidays */
 	tm = time_to_tm(curr_week + wday*86400);
-	if (errmsg = parse_holidays(tm->tm_year, FALSE))
+	if ((errmsg = parse_holidays(tm->tm_year, FALSE)))
 		create_error_popup(mainmenu.cal, 0, errmsg);
 	shp = &sm_holiday[tm->tm_yday];
 	hp  =    &holiday[tm->tm_yday];
@@ -368,6 +370,20 @@ static void draw_week_day_background(
 	g_setcolor(COL_WBOXBACK);
 	g_fillrect(x, y, week.canvas_xs - c->week_margin - x,
 			 week.nlines[wday] * ys);
+							/* repeated times */
+	if (wday && c->week_gap > font[FONT_WHOUR]->max_bounds.ascent-2
+		 && drawn_lines > 10) {
+		drawn_lines -= 10;
+		g_setcolor(COL_WDAY);
+		g_setfont(FONT_WHOUR);
+		for (i=0; i < c->week_maxhour-c->week_minhour; i++) {
+			char buf[10];
+			sprintf(buf, "%d", i + c->week_minhour);
+			g_drawtext(x + i * c->week_hourwidth + 2, y - 1,
+						buf, strlen(buf));
+		}
+	}
+	drawn_lines += week.nlines[wday];
 }
 
 
@@ -378,13 +394,13 @@ static void draw_week_day_background(
  */
 
 static void draw_week_day_foreground(
-	int			wday)		/* day of the week, < NDAYS */
+	int		wday)		/* day of the week, < NDAYS */
 {
-	register struct config	*c = &config;
-	struct weeknode		*vert, *horz;	/* week node scan pointers */
-	int			x, y;		/* upper left of day bk box */
-	int			ys;		/* height of bar line w/ gaps*/
-	int			i, u;
+	struct config	*c = &config;
+	struct weeknode	*vert, *horz;	/* week node scan pointers */
+	int		x, y;		/* upper left of day bk box */
+	int		ys;		/* height of bar line w/ gaps*/
+	int		i, u;
 
 	x  = c->week_margin + c->week_daywidth + c->week_gap;
 	y  = 2*c->week_margin + c->week_title + c->week_hour + c->week_gap + 2;
@@ -406,23 +422,23 @@ static void draw_week_day_foreground(
  */
 
 static void draw_bar(
-	struct weeknode		*node,		/* entry node to print */
-	int			color,		/* color, 0..7 */
-	int			x,		/* top left pos in canvas */
-	int			y)
+	struct weeknode	*node,		/* entry node to print */
+	int		color,		/* color, 0..7 */
+	int		x,		/* top left pos in canvas */
+	int		y)
 {
-	register struct entry	*ep = node->entry;
-	register struct config	*c = &config;
-	int			xend;		/* right margin of chart */
-	int			w[2], b, e;	/* early/late, begin, end */
-	int			ee;		/* e with min length applied */
-	int			i;		/* warning counter, 0..1 */
-	int			slope;		/* delta-x of the arrowheads */
-	XPoint			point[7];	/* polygon vertex list */
+	struct entry	*ep = node->entry;
+	struct config	*c = &config;
+	int		xend;		/* right margin of chart */
+	int		w[2], b, e;	/* early/late, begin, end */
+	int		ee;		/* e with min length applied */
+	int		i;		/* warning counter, 0..1 */
+	int		slope;		/* delta-x of the arrowheads */
+	XPoint		point[7];	/* polygon vertex list */
 #ifdef JAPAN
-	int			plen;		/* pixel-length of partialstr */
-	strpack			partialstr[MAXPARTIALSTRING];
-	unsigned char		strpool[MAXPARTIALCHAR];
+	int		plen;		/* pixel-length of partialstr */
+	strpack		partialstr[MAXPARTIALSTRING];
+	unsigned char	strpool[MAXPARTIALCHAR];
 #endif
 
 	slope = c->week_barheight * SLOPE;
