@@ -149,13 +149,14 @@ void set_icon(
 	Pixmap			icon;
 
 	if (!config.noicon && !sub)
-		if (icon = XCreatePixmapFromBitmapData(display,
+		if ((icon = XCreatePixmapFromBitmapData(display,
 				DefaultRootWindow(display),
 				sub ? iconsub_bits : icon_bits,
 				icon_width, icon_height,
 				WhitePixelOfScreen(XtScreen(shell)),
 				BlackPixelOfScreen(XtScreen(shell)),
-				DefaultDepth(display, DefaultScreen(display))))
+				DefaultDepth(display,
+				DefaultScreen(display)))))
 
 			XtVaSetValues(shell, XmNiconPixmap, icon, NULL);
 	print_icon_name();
@@ -197,10 +198,10 @@ void print_icon_name(void)
  */
 
 int strlen_in_pixels(
-	register char	*string,	/* string to truncate */
+	char		*string,	/* string to truncate */
 	int		sfont)		/* FONT_* */
 {
-	register int	len;		/* length in pixels */
+	int		len;		/* length in pixels */
 
 	for (len=0; *string; string++)
 		len += CHARWIDTH(sfont, *string);
@@ -214,8 +215,8 @@ int strlen_in_pixels(
  */
 
 void truncate_string(
-	register char	*string,	/* string to truncate */
-	register int	len,		/* max len in pixels */
+	char		*string,	/* string to truncate */
+	int		len,		/* max len in pixels */
 	int		sfont)		/* font of string */
 {
 	while (*string) {
@@ -413,7 +414,7 @@ void drag_destroy(
 
 /*ARGSUSED*/
 static void expose_callback(
-	Widget				canvas,		/* drawing area */
+	UNUSED Widget			canvas,		/* drawing area */
 	XtPointer			data,		/* view: 0..NVIEWS-1 */
 	XmDrawingAreaCallbackStruct	*info)		/* what & where */
 {
@@ -441,7 +442,7 @@ static void canvas_callback(
 	Widget		canvas,		/* canvas, == calendar drawing area */
 	XButtonEvent	*event,		/* X event, contains position */
 	String		*args,		/* what happened, up/down/motion */
-	int		nargs)		/* # of args, must be 1 */
+	UNUSED int	nargs)		/* # of args, must be 1 */
 {
 	static struct entry *entry;	/* entry being dragged */
 	static BOOL	warn;		/* just the n-days-ahead copy? */
@@ -454,7 +455,8 @@ static void canvas_callback(
 	MOUSE		m;		/* target area being moved to */
 	time_t		time;		/* current mouse time */
 	struct dragc_s	*dc;		/* drag context for callbacks */
-	int		x, y, xs, ys;	/* new item start and size */
+	int		x=0, y=0;	/* new item start */
+	int		xs=0, ys=0;	/* new item size */
 	int		dx, dy;		/* movement since initial press */
 	char		buf[1024];	/* for date string */
 	int		i;
