@@ -96,14 +96,14 @@ void build_yov(
 				continue;
 			if (!lookup.days_warn)
 				ep->ignore = ignore_id;
-			if (ep->hide_in_o || ep->private && omit_priv)
+			if (ep->hide_in_o || (ep->private && omit_priv))
 				continue;
 			if (!c->yov_single && ep->rep_every != 86400)
 				continue;
 			u = name_to_user(ep->user);
-			if (c->yov_display == 0 && user[u].suspend_o	||
-			    c->yov_display == 2 && u != 0		||
-			    c->yov_display == 3 && u != c->yov_user)
+			if ((c->yov_display == 0 && user[u].suspend_o)	||
+			    (c->yov_display == 2 && u != 0)		||
+			    (c->yov_display == 3 && u != c->yov_user))
 				continue;
 			trigger = lookup.trigger - lookup.trigger % 86400;
 			if (ep->rep_every != 86400) {
