@@ -368,9 +368,9 @@ void create_yov_menu(
 
 /*ARGSUSED*/
 static void next_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct tm			*tm;
 
@@ -384,9 +384,9 @@ static void next_callback(
 
 /*ARGSUSED*/
 static void done_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (parent_form)
 		create_view('m');
@@ -397,9 +397,9 @@ static void done_callback(
 
 /*ARGSUSED*/
 static void edit_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	struct tm *tm = time_to_tm(curr_yov);
 	create_list_popup(mainlist, curr_yov,
@@ -410,9 +410,9 @@ static void edit_callback(
 
 /*ARGSUSED*/
 static void sync_callback(
-	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED Widget			widget,
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	if (!can_edit_appts())
 		return;
@@ -430,8 +430,8 @@ static void sync_callback(
 /*ARGSUSED*/
 static void zoom_callback(
 	Widget				w,
-	int				data,
-	XmDrawingAreaCallbackStruct	*info)
+	UNUSED int			data,
+	UNUSED XmDrawingAreaCallbackStruct*info)
 {
 	XmScaleGetValue(w, &config.yov_nmonths);
 	config.yov_nmonths = sl2nm[config.yov_nmonths];
@@ -447,8 +447,8 @@ static void zoom_callback(
 
 /*ARGSUSED*/
 static void single_callback(
-	Widget				widget,
-	int				item,
+	UNUSED Widget			widget,
+	UNUSED int			item,
 	XmToggleButtonCallbackStruct	*data)
 {
 	config.yov_single = data->set;
@@ -460,9 +460,9 @@ static void single_callback(
 
 /*ARGSUSED*/
 static void disp_callback(
-	Widget				widget,
+	UNUSED Widget			widget,
 	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	Arg				args;
 	int				i;
@@ -495,8 +495,8 @@ static void callback(
 /*ARGSUSED*/
 static void other_callback(
 	Widget				widget,
-	int				item,
-	XmToggleButtonCallbackStruct	*data)
+	UNUSED int			item,
+	UNUSED XmToggleButtonCallbackStruct*data)
 {
 	create_user_sel_popup(widget, config.yov_user, (BOOL (*)())callback);
 }
